searchData={"items":[{"type":"module","title":"SmeeView","doc":"SmeeView provides two types of module for extracting information from SAML metadata, loosely based on the concept\nof functional data access \"lenses\". SmeeView extends the [Smee](https://hexdocs.pm/smee/readme.html) library and requires\n  metadata to be contained in individual `Smee.Entity` records.","ref":"SmeeView.html"},{"type":"module","title":"Views - SmeeView","doc":"Views take metadata, or information extracted from metadata, and return a specific type of record from it, known as an\n  aspect. They also allow further filtering and processing of lists of aspects.\n\nFor instance `SmeeView.Logos` will extract all logo information from an entity's metadata and filter them so that only\n  IdP logos of a particular shape are returned. The `SmeeView.EntityAttributes` module has lots of useful tools for\n gathering information about entities from their entity attributes (particularly if you can never remember any of the\nURIs like me)","ref":"SmeeView.html#module-views"},{"type":"module","title":"Aspects - SmeeView","doc":"Each fragment of information extracted from metadata by a View is an *aspect*. Aspects contain most (if not all) of\nthe information present in the original metadata. Aspect modules provide ways to view or process that information.","ref":"SmeeView.html#module-aspects"},{"type":"module","title":"Convenience functions - SmeeView","doc":"The top-level `SmeeView` module contains shortcuts to the view functions of every View module, and is the easiest way\n  to get started. Each function below will return any available aspects from the entity metadata.","ref":"SmeeView.html#module-convenience-functions"},{"type":"module","title":"References and further reading - SmeeView","doc":"SmeeView does not document SAML Metadata itself - you'll need to read about that elsewhere if you have questions about\n  how the information is used. The following resources will be of help:\n\n* [Incommon's Guide to SAML Metadata](https://spaces.at.internet2.edu/display/federation/metadata-saml) - very clear and readable\n* [OASIS Simplified Overview of SAML Metadata](https://www.oasis-open.org/committees/download.php/51890/SAML%20MD%20simplified%20overview.pdf)\n* [Wikipedia: SAML Metadata](https://en.wikipedia.org/wiki/SAML_metadata) Has technical overview, history and protocol walkthrough","ref":"SmeeView.html#module-references-and-further-reading"},{"type":"function","title":"SmeeView.prism/2","doc":"Returns a map of `SmeeView.Aspect.Entity` aspect structs extracted from the input data, with entity IDs as keys.\n Each entity aspect represents an entire SAML entity, and contains lists of other aspect structs representing each\n \"aspect\" of the entity.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/2` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one type of aspect from a single `Smee.Entity` struct then you should probably use `view/2` instead.\n\n```\nSmeeView.prism(entity)\n# => %{\"https://example.com/shibboleth\" => [%Entity{}]}\n\nSmeeView.prism(metadata)\n# => %{\"https://example.com/shibboleth\" => [%Entity{}, %Entity{}, ...]}\n```","ref":"SmeeView.html#prism/2"},{"type":"function","title":"SmeeView.view/2","doc":"Returns a list of `SmeeView.Aspect.Entity` structs extracted from the input data. Each one represents an entire SAML\n  entity, and contains lists of other aspect structs representing each \"aspect\" of the entity.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/2` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata files it's often\n  better to use `prism/2` which returns the same data in a map, associated with each entity's ID.\n\n```\nSmeeView.view(entity)\n# => [%Entity{}]\n\nSmeeView.view(metadata)\n# => [%Entity{}, %Entity{}, %Entity{}, ...]\n\nSmeeView.view([metadata, entity1, entity2])\n# => [%Entity{}, %Entity{}, %Entity{}, ...]\n\n```","ref":"SmeeView.html#view/2"},{"type":"function","title":"SmeeView.view_one/2","doc":"Returns a single `SmeeView.Aspect.Entity` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n **Only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists the first suitable aspect found will be returned. It may not be from the first\n  entity, if the first entity has no suitable content.\n\n`view_one/2` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n```\nSmeeView.view_one(entity)\n# => %Entity{}\n\nSmeeView.view_one(metadata)\n# => %Entity{}\n\n```","ref":"SmeeView.html#view_one/2"},{"type":"module","title":"SmeeView.ArtifactResolutionServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.ArtifactResolutionServices.html"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nArtifactResolutionServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.ArtifactResolutionServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nArtifactResolutionServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.ArtifactResolutionServices.html#bindings/1"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nArtifactResolutionServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.ArtifactResolutionServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.ArtifactResolutionService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nArtifactResolutionServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.ArtifactResolutionService{}, %Elixir.SmeeView.Aspects.ArtifactResolutionService{},]}\n```","ref":"SmeeView.ArtifactResolutionServices.html#prism/3"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nArtifactResolutionServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.ArtifactResolutionServices.html#sort/1"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nArtifactResolutionServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.ArtifactResolutionServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.ArtifactResolutionService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nArtifactResolutionServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.ArtifactResolutionService{}, %Elixir.SmeeView.Aspects.ArtifactResolutionService{}]\n```","ref":"SmeeView.ArtifactResolutionServices.html#view/3"},{"type":"function","title":"SmeeView.ArtifactResolutionServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.ArtifactResolutionService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nArtifactResolutionServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.ArtifactResolutionService{}\n```","ref":"SmeeView.ArtifactResolutionServices.html#view_one/3"},{"type":"module","title":"SmeeView.AssertionConsumerServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.AssertionConsumerServices.html"},{"type":"function","title":"SmeeView.AssertionConsumerServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nAssertionConsumerServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.AssertionConsumerServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.AssertionConsumerServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nAssertionConsumerServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.AssertionConsumerServices.html#bindings/1"},{"type":"function","title":"SmeeView.AssertionConsumerServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nAssertionConsumerServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.AssertionConsumerServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.AssertionConsumerServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.AssertionConsumerService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAssertionConsumerServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.AssertionConsumerService{}, %Elixir.SmeeView.Aspects.AssertionConsumerService{},]}\n```","ref":"SmeeView.AssertionConsumerServices.html#prism/3"},{"type":"function","title":"SmeeView.AssertionConsumerServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nAssertionConsumerServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.AssertionConsumerServices.html#sort/1"},{"type":"function","title":"SmeeView.AssertionConsumerServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nAssertionConsumerServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.AssertionConsumerServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.AssertionConsumerServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.AssertionConsumerService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAssertionConsumerServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.AssertionConsumerService{}, %Elixir.SmeeView.Aspects.AssertionConsumerService{}]\n```","ref":"SmeeView.AssertionConsumerServices.html#view/3"},{"type":"function","title":"SmeeView.AssertionConsumerServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.AssertionConsumerService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAssertionConsumerServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.AssertionConsumerService{}\n```","ref":"SmeeView.AssertionConsumerServices.html#view_one/3"},{"type":"module","title":"SmeeView.AssertionIDRequestServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.AssertionIDRequestServices.html"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nAssertionIDRequestServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.AssertionIDRequestServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nAssertionIDRequestServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.AssertionIDRequestServices.html#bindings/1"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nAssertionIDRequestServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.AssertionIDRequestServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.AssertionIDRequestService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAssertionIDRequestServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.AssertionIDRequestService{}, %Elixir.SmeeView.Aspects.AssertionIDRequestService{},]}\n```","ref":"SmeeView.AssertionIDRequestServices.html#prism/3"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nAssertionIDRequestServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.AssertionIDRequestServices.html#sort/1"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nAssertionIDRequestServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.AssertionIDRequestServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.AssertionIDRequestService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAssertionIDRequestServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.AssertionIDRequestService{}, %Elixir.SmeeView.Aspects.AssertionIDRequestService{}]\n```","ref":"SmeeView.AssertionIDRequestServices.html#view/3"},{"type":"function","title":"SmeeView.AssertionIDRequestServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.AssertionIDRequestService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAssertionIDRequestServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.AssertionIDRequestService{}\n```","ref":"SmeeView.AssertionIDRequestServices.html#view_one/3"},{"type":"module","title":"SmeeView.AttributeConsumingServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.AttributeConsumingServices.html"},{"type":"function","title":"SmeeView.AttributeConsumingServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nAttributeConsumingServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.AttributeConsumingServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.AttributeConsumingServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.AttributeConsumingService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributeConsumingServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.AttributeConsumingService{}, %Elixir.SmeeView.Aspects.AttributeConsumingService{},]}\n```","ref":"SmeeView.AttributeConsumingServices.html#prism/3"},{"type":"function","title":"SmeeView.AttributeConsumingServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nAttributeConsumingServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.AttributeConsumingServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.AttributeConsumingServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.AttributeConsumingService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributeConsumingServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.AttributeConsumingService{}, %Elixir.SmeeView.Aspects.AttributeConsumingService{}]\n```","ref":"SmeeView.AttributeConsumingServices.html#view/3"},{"type":"function","title":"SmeeView.AttributeConsumingServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.AttributeConsumingService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributeConsumingServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.AttributeConsumingService{}\n```","ref":"SmeeView.AttributeConsumingServices.html#view_one/3"},{"type":"module","title":"SmeeView.AttributeServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.AttributeServices.html"},{"type":"function","title":"SmeeView.AttributeServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nAttributeServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.AttributeServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.AttributeServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nAttributeServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.AttributeServices.html#bindings/1"},{"type":"function","title":"SmeeView.AttributeServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nAttributeServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.AttributeServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.AttributeServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.AttributeService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributeServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.AttributeService{}, %Elixir.SmeeView.Aspects.AttributeService{},]}\n```","ref":"SmeeView.AttributeServices.html#prism/3"},{"type":"function","title":"SmeeView.AttributeServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nAttributeServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.AttributeServices.html#sort/1"},{"type":"function","title":"SmeeView.AttributeServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nAttributeServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.AttributeServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.AttributeServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.AttributeService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributeServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.AttributeService{}, %Elixir.SmeeView.Aspects.AttributeService{}]\n```","ref":"SmeeView.AttributeServices.html#view/3"},{"type":"function","title":"SmeeView.AttributeServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.AttributeService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributeServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.AttributeService{}\n```","ref":"SmeeView.AttributeServices.html#view_one/3"},{"type":"module","title":"SmeeView.Attributes","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Attributes.html"},{"type":"function","title":"SmeeView.Attributes.contain?/2","doc":"Returns true if the aspects contain the specified attribute name\n\n```\n  Attributes.contain?(attrs, \"urn:oid:1.3.6.1.4.1.5923.1.1.1.6\")\n# => true\n\n\n```","ref":"SmeeView.Attributes.html#contain?/2"},{"type":"function","title":"SmeeView.Attributes.contain_friendly?/2","doc":"Returns true if the aspects contain the specified attribute friendly name\n\n```\n  Attributes.contain?(attrs, \"sn\")\n# => true\n\n\n```","ref":"SmeeView.Attributes.html#contain_friendly?/2"},{"type":"function","title":"SmeeView.Attributes.friendly_names/1","doc":"Returns a list of all attribute names (full, technical, URI names).\n\nThe results are sorted and each value is unique.\n\n```\n  Attributes.friendly_names(attrs)\n# => [\"eduPersonPrincipalName\", \"email\", \"organizationName\"]\n```","ref":"SmeeView.Attributes.html#friendly_names/1"},{"type":"function","title":"SmeeView.Attributes.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nAttributes.idp_filter(view)\n# => []\n```","ref":"SmeeView.Attributes.html#idp_filter/1"},{"type":"function","title":"SmeeView.Attributes.names/1","doc":"Returns a list of all attribute names (full, technical, URI names).\n\nThe results are sorted and each value is unique.\n\n```\n  Attributes.names(attrs)\n# => [\"urn:oid:1.3.6.1.4.1.5923.1.1.1.6\", \"urn:oid:0.9.2342.19200300.100.1.3\", \"urn:oid:2.5.4.10\"]\n```","ref":"SmeeView.Attributes.html#names/1"},{"type":"function","title":"SmeeView.Attributes.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Attribute` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributes.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Attribute{}, %Elixir.SmeeView.Aspects.Attribute{},]}\n```","ref":"SmeeView.Attributes.html#prism/3"},{"type":"function","title":"SmeeView.Attributes.saml1_filter/1","doc":"Returns only SAML1 attributes\n\nFilters the view (list) or prism (map) to only include SAML1 attributes\n\n```\nAttributes.saml1_filter(aspects)\n# =>  [%Elixir.SmeeView.Aspects.Attribute{}]\n```","ref":"SmeeView.Attributes.html#saml1_filter/1"},{"type":"function","title":"SmeeView.Attributes.saml2_filter/1","doc":"Returns only SAML2 attributes\n\nFilters the view (list) or prism (map) to only include SAML2 attributes\n\n```\nAttributes.saml2_filter(aspects)\n# => [%Elixir.SmeeView.Aspects.Attribute{}]\n```","ref":"SmeeView.Attributes.html#saml2_filter/1"},{"type":"function","title":"SmeeView.Attributes.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nAttributes.sp_filter(view)\n# => []\n```","ref":"SmeeView.Attributes.html#sp_filter/1"},{"type":"function","title":"SmeeView.Attributes.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Attribute` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributes.view(entity)\n# => [%Elixir.SmeeView.Aspects.Attribute{}, %Elixir.SmeeView.Aspects.Attribute{}]\n```","ref":"SmeeView.Attributes.html#view/3"},{"type":"function","title":"SmeeView.Attributes.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Attribute` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nAttributes.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Attribute{}\n```","ref":"SmeeView.Attributes.html#view_one/3"},{"type":"module","title":"SmeeView.Contacts","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Contacts.html"},{"type":"function","title":"SmeeView.Contacts.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nContacts.idp_filter(view)\n# => []\n```","ref":"SmeeView.Contacts.html#idp_filter/1"},{"type":"function","title":"SmeeView.Contacts.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Contact` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nContacts.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Contact{}, %Elixir.SmeeView.Aspects.Contact{},]}\n```","ref":"SmeeView.Contacts.html#prism/3"},{"type":"function","title":"SmeeView.Contacts.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nContacts.sp_filter(view)\n# => []\n```","ref":"SmeeView.Contacts.html#sp_filter/1"},{"type":"function","title":"SmeeView.Contacts.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Contact` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nContacts.view(entity)\n# => [%Elixir.SmeeView.Aspects.Contact{}, %Elixir.SmeeView.Aspects.Contact{}]\n```","ref":"SmeeView.Contacts.html#view/3"},{"type":"function","title":"SmeeView.Contacts.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Contact` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nContacts.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Contact{}\n```","ref":"SmeeView.Contacts.html#view_one/3"},{"type":"module","title":"SmeeView.Descriptions","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Descriptions.html"},{"type":"function","title":"SmeeView.Descriptions.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDescriptions.idp_filter(view)\n# => []\n```","ref":"SmeeView.Descriptions.html#idp_filter/1"},{"type":"function","title":"SmeeView.Descriptions.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Description` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDescriptions.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Description{}, %Elixir.SmeeView.Aspects.Description{},]}\n```","ref":"SmeeView.Descriptions.html#prism/3"},{"type":"function","title":"SmeeView.Descriptions.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDescriptions.sp_filter(view)\n# => []\n```","ref":"SmeeView.Descriptions.html#sp_filter/1"},{"type":"function","title":"SmeeView.Descriptions.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Description` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDescriptions.view(entity)\n# => [%Elixir.SmeeView.Aspects.Description{}, %Elixir.SmeeView.Aspects.Description{}]\n```","ref":"SmeeView.Descriptions.html#view/3"},{"type":"function","title":"SmeeView.Descriptions.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Description` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDescriptions.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Description{}\n```","ref":"SmeeView.Descriptions.html#view_one/3"},{"type":"module","title":"SmeeView.DigestMethods","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.DigestMethods.html"},{"type":"function","title":"SmeeView.DigestMethods.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDigestMethods.idp_filter(view)\n# => []\n```","ref":"SmeeView.DigestMethods.html#idp_filter/1"},{"type":"function","title":"SmeeView.DigestMethods.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.DigestMethod` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDigestMethods.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.DigestMethod{}, %Elixir.SmeeView.Aspects.DigestMethod{},]}\n```","ref":"SmeeView.DigestMethods.html#prism/3"},{"type":"function","title":"SmeeView.DigestMethods.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDigestMethods.sp_filter(view)\n# => []\n```","ref":"SmeeView.DigestMethods.html#sp_filter/1"},{"type":"function","title":"SmeeView.DigestMethods.truncate/1","doc":"Shortens algorithms\n\nRemoves the URI namespacing prefix from algorithms, making them smaller, friendlier, and potentially conflicting.\n\n```\nDigestMethods.truncate(aspects)\n# => [\"ecdsa-sha1\"]\n```","ref":"SmeeView.DigestMethods.html#truncate/1"},{"type":"function","title":"SmeeView.DigestMethods.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.DigestMethod` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDigestMethods.view(entity)\n# => [%Elixir.SmeeView.Aspects.DigestMethod{}, %Elixir.SmeeView.Aspects.DigestMethod{}]\n```","ref":"SmeeView.DigestMethods.html#view/3"},{"type":"function","title":"SmeeView.DigestMethods.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.DigestMethod` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDigestMethods.view_one(entity)\n# => %Elixir.SmeeView.Aspects.DigestMethod{}\n```","ref":"SmeeView.DigestMethods.html#view_one/3"},{"type":"module","title":"SmeeView.DiscoHints","doc":"This module can extracts a bundle of related Discovery (\"Disco\") elements from entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.DiscoHints.html"},{"type":"function","title":"SmeeView.DiscoHints.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDiscoHints.idp_filter(view)\n# => []\n```","ref":"SmeeView.DiscoHints.html#idp_filter/1"},{"type":"function","title":"SmeeView.DiscoHints.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.DiscoHints` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoHints.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.DiscoHints{}, %Elixir.SmeeView.Aspects.DiscoHints{},]}\n```","ref":"SmeeView.DiscoHints.html#prism/3"},{"type":"function","title":"SmeeView.DiscoHints.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDiscoHints.sp_filter(view)\n# => []\n```","ref":"SmeeView.DiscoHints.html#sp_filter/1"},{"type":"function","title":"SmeeView.DiscoHints.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.DiscoHints` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoHints.view(entity)\n# => [%Elixir.SmeeView.Aspects.DiscoHints{}, %Elixir.SmeeView.Aspects.DiscoHints{}]\n```","ref":"SmeeView.DiscoHints.html#view/3"},{"type":"function","title":"SmeeView.DiscoHints.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.DiscoHints` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoHints.view_one(entity)\n# => %Elixir.SmeeView.Aspects.DiscoHints{}\n```","ref":"SmeeView.DiscoHints.html#view_one/3"},{"type":"module","title":"SmeeView.DiscoUIs","doc":"This module can extracts a bundle of related Metadata UI (\"mdui:\") aspects from entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.DiscoUIs.html"},{"type":"function","title":"SmeeView.DiscoUIs.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDiscoUIs.idp_filter(view)\n# => []\n```","ref":"SmeeView.DiscoUIs.html#idp_filter/1"},{"type":"function","title":"SmeeView.DiscoUIs.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.DiscoUI` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoUIs.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.DiscoUI{}, %Elixir.SmeeView.Aspects.DiscoUI{},]}\n```","ref":"SmeeView.DiscoUIs.html#prism/3"},{"type":"function","title":"SmeeView.DiscoUIs.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDiscoUIs.sp_filter(view)\n# => []\n```","ref":"SmeeView.DiscoUIs.html#sp_filter/1"},{"type":"function","title":"SmeeView.DiscoUIs.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.DiscoUI` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoUIs.view(entity)\n# => [%Elixir.SmeeView.Aspects.DiscoUI{}, %Elixir.SmeeView.Aspects.DiscoUI{}]\n```","ref":"SmeeView.DiscoUIs.html#view/3"},{"type":"function","title":"SmeeView.DiscoUIs.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.DiscoUI` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoUIs.view_one(entity)\n# => %Elixir.SmeeView.Aspects.DiscoUI{}\n```","ref":"SmeeView.DiscoUIs.html#view_one/3"},{"type":"module","title":"SmeeView.DiscoveryResponses","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.DiscoveryResponses.html"},{"type":"function","title":"SmeeView.DiscoveryResponses.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nDiscoveryResponses.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.DiscoveryResponses.html#binding_filter/2"},{"type":"function","title":"SmeeView.DiscoveryResponses.bindings/1","doc":"Returns all bindings present in the view\n\n```\nDiscoveryResponses.bindings(aspects)\n# => []\n```","ref":"SmeeView.DiscoveryResponses.html#bindings/1"},{"type":"function","title":"SmeeView.DiscoveryResponses.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDiscoveryResponses.idp_filter(view)\n# => []\n```","ref":"SmeeView.DiscoveryResponses.html#idp_filter/1"},{"type":"function","title":"SmeeView.DiscoveryResponses.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.DiscoveryResponse` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoveryResponses.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.DiscoveryResponse{}, %Elixir.SmeeView.Aspects.DiscoveryResponse{},]}\n```","ref":"SmeeView.DiscoveryResponses.html#prism/3"},{"type":"function","title":"SmeeView.DiscoveryResponses.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nDiscoveryResponses.sort(aspect)\n# => [...]\n```","ref":"SmeeView.DiscoveryResponses.html#sort/1"},{"type":"function","title":"SmeeView.DiscoveryResponses.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDiscoveryResponses.sp_filter(view)\n# => []\n```","ref":"SmeeView.DiscoveryResponses.html#sp_filter/1"},{"type":"function","title":"SmeeView.DiscoveryResponses.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.DiscoveryResponse` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoveryResponses.view(entity)\n# => [%Elixir.SmeeView.Aspects.DiscoveryResponse{}, %Elixir.SmeeView.Aspects.DiscoveryResponse{}]\n```","ref":"SmeeView.DiscoveryResponses.html#view/3"},{"type":"function","title":"SmeeView.DiscoveryResponses.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.DiscoveryResponse` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDiscoveryResponses.view_one(entity)\n# => %Elixir.SmeeView.Aspects.DiscoveryResponse{}\n```","ref":"SmeeView.DiscoveryResponses.html#view_one/3"},{"type":"module","title":"SmeeView.Displaynames","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Displaynames.html"},{"type":"function","title":"SmeeView.Displaynames.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDisplaynames.idp_filter(view)\n# => []\n```","ref":"SmeeView.Displaynames.html#idp_filter/1"},{"type":"function","title":"SmeeView.Displaynames.langs/1","doc":"Returns all languages used in the list (view) or map (prism)\n\n```\nDisplaynames.langs(aspects)\n# => [\"en\", \"se\", \"zu\"]\n```","ref":"SmeeView.Displaynames.html#langs/1"},{"type":"function","title":"SmeeView.Displaynames.max_size/1","doc":"Returns maximum width of text in the view, as an integer\n\n```\nDisplaynames.max_size(aspects)\n# => 42\n```","ref":"SmeeView.Displaynames.html#max_size/1"},{"type":"function","title":"SmeeView.Displaynames.pick/2","doc":"Returns the first aspect with matching language, or failing that, the default language, or English\n\nThis function is useful when showing a UI to users, to select the most appropriate aspect for display\n\n```\nDisplaynames.pick(aspects, \"no\")\n# => %Elixir.SmeeView.Aspects.Displayname{lang: \"no\" text: \"...\" }\n```","ref":"SmeeView.Displaynames.html#pick/2"},{"type":"function","title":"SmeeView.Displaynames.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Displayname` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDisplaynames.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Displayname{}, %Elixir.SmeeView.Aspects.Displayname{},]}\n```","ref":"SmeeView.Displaynames.html#prism/3"},{"type":"function","title":"SmeeView.Displaynames.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDisplaynames.sp_filter(view)\n# => []\n```","ref":"SmeeView.Displaynames.html#sp_filter/1"},{"type":"function","title":"SmeeView.Displaynames.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Displayname` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDisplaynames.view(entity)\n# => [%Elixir.SmeeView.Aspects.Displayname{}, %Elixir.SmeeView.Aspects.Displayname{}]\n```","ref":"SmeeView.Displaynames.html#view/3"},{"type":"function","title":"SmeeView.Displaynames.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Displayname` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDisplaynames.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Displayname{}\n```","ref":"SmeeView.Displaynames.html#view_one/3"},{"type":"module","title":"SmeeView.Domains","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Domains.html"},{"type":"function","title":"SmeeView.Domains.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nDomains.idp_filter(view)\n# => []\n```","ref":"SmeeView.Domains.html#idp_filter/1"},{"type":"function","title":"SmeeView.Domains.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Domain` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDomains.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Domain{}, %Elixir.SmeeView.Aspects.Domain{},]}\n```","ref":"SmeeView.Domains.html#prism/3"},{"type":"function","title":"SmeeView.Domains.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nDomains.sp_filter(view)\n# => []\n```","ref":"SmeeView.Domains.html#sp_filter/1"},{"type":"function","title":"SmeeView.Domains.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Domain` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDomains.view(entity)\n# => [%Elixir.SmeeView.Aspects.Domain{}, %Elixir.SmeeView.Aspects.Domain{}]\n```","ref":"SmeeView.Domains.html#view/3"},{"type":"function","title":"SmeeView.Domains.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Domain` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nDomains.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Domain{}\n```","ref":"SmeeView.Domains.html#view_one/3"},{"type":"module","title":"SmeeView.EncryptionMethods","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.EncryptionMethods.html"},{"type":"function","title":"SmeeView.EncryptionMethods.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nEncryptionMethods.idp_filter(view)\n# => []\n```","ref":"SmeeView.EncryptionMethods.html#idp_filter/1"},{"type":"function","title":"SmeeView.EncryptionMethods.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.EncryptionMethod` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEncryptionMethods.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.EncryptionMethod{}, %Elixir.SmeeView.Aspects.EncryptionMethod{},]}\n```","ref":"SmeeView.EncryptionMethods.html#prism/3"},{"type":"function","title":"SmeeView.EncryptionMethods.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nEncryptionMethods.sp_filter(view)\n# => []\n```","ref":"SmeeView.EncryptionMethods.html#sp_filter/1"},{"type":"function","title":"SmeeView.EncryptionMethods.truncate/1","doc":"Shortens algorithms\n\nRemoves the URI namespacing prefix from algorithms, making them smaller, friendlier, and potentially conflicting.\n\n```\nEncryptionMethods.truncate(aspects)\n# => [\"ecdsa-sha1\"]\n```","ref":"SmeeView.EncryptionMethods.html#truncate/1"},{"type":"function","title":"SmeeView.EncryptionMethods.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.EncryptionMethod` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEncryptionMethods.view(entity)\n# => [%Elixir.SmeeView.Aspects.EncryptionMethod{}, %Elixir.SmeeView.Aspects.EncryptionMethod{}]\n```","ref":"SmeeView.EncryptionMethods.html#view/3"},{"type":"function","title":"SmeeView.EncryptionMethods.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.EncryptionMethod` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEncryptionMethods.view_one(entity)\n# => %Elixir.SmeeView.Aspects.EncryptionMethod{}\n```","ref":"SmeeView.EncryptionMethods.html#view_one/3"},{"type":"module","title":"SmeeView.Entities","doc":"This module can extract a bundle of related aspects from entity metadata. It is the top-level structure for SmeeView,\n  and contains all other aspects - as such it is the slowest and least efficient. If you only need a few types of data\n  please use the dedicated modules for each instead of the module.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Entities.html"},{"type":"function","title":"SmeeView.Entities.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nEntities.idp_filter(view)\n# => []\n```","ref":"SmeeView.Entities.html#idp_filter/1"},{"type":"function","title":"SmeeView.Entities.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Entity` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEntities.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Entity{}, %Elixir.SmeeView.Aspects.Entity{},]}\n```","ref":"SmeeView.Entities.html#prism/3"},{"type":"function","title":"SmeeView.Entities.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nEntities.sp_filter(view)\n# => []\n```","ref":"SmeeView.Entities.html#sp_filter/1"},{"type":"function","title":"SmeeView.Entities.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Entity` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEntities.view(entity)\n# => [%Elixir.SmeeView.Aspects.Entity{}, %Elixir.SmeeView.Aspects.Entity{}]\n```","ref":"SmeeView.Entities.html#view/3"},{"type":"function","title":"SmeeView.Entities.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Entity` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEntities.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Entity{}\n```","ref":"SmeeView.Entities.html#view_one/3"},{"type":"module","title":"SmeeView.EntityAttributes","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.EntityAttributes.html"},{"type":"function","title":"SmeeView.EntityAttributes.assurance_certifications/1","doc":"Lists the values for `urn:oasis:names:tc:SAML:attribute:assurance-certification` entity attributes\n\n```\nSmeeView.EntityAttributes.assurance_certifications(ent_attrs)\n# => [\"http://refeds.org/sirtfi\", \"http://www.swamid.se/policy/assurance/al1\",\n# \"https://refeds.org/sirtfi2\"]\n```","ref":"SmeeView.EntityAttributes.html#assurance_certifications/1"},{"type":"function","title":"SmeeView.EntityAttributes.category?/2","doc":"Returns true if any of the attributes contains the entity category\n\n```\nSmeeView.EntityAttributes.category?(ent_attrs, \"https://myacademicid.org/entity-categories/esi\")\n# => false\n```","ref":"SmeeView.EntityAttributes.html#category?/2"},{"type":"function","title":"SmeeView.EntityAttributes.coco?/1","doc":"Returns true if any of the attributes indicate CoCo (Code of Conduct) status\n\n\n```\nSmeeView.EntityAttributes.coco?(ent_attrs)\n# => true\n```","ref":"SmeeView.EntityAttributes.html#coco?/1"},{"type":"function","title":"SmeeView.EntityAttributes.contain?/2","doc":"Returns true if the aspects contain the specified attribute name\n\n```\nSmeeView.EntityAttributes.contain?(ent_attrs, \"urn:oasis:names:tc:SAML:attribute:assurance-certification\")\n# => true\n\n\n```","ref":"SmeeView.EntityAttributes.html#contain?/2"},{"type":"function","title":"SmeeView.EntityAttributes.contain?/3","doc":"Returns true if the aspects contain the specified attribute type/name and value\n\n```\nSmeeView.EntityAttributes.contain?(ent_attrs, \"urn:oasis:names:tc:SAML:attribute:assurance-certification\", \"https://refeds.org/sirtfi2\")\n# => true\n```","ref":"SmeeView.EntityAttributes.html#contain?/3"},{"type":"function","title":"SmeeView.EntityAttributes.entity_categories/1","doc":"Lists all values for entity category (`http://macedir.org/entity-category`) entity attributes\n\n```\nSmeeView.EntityAttributes.entity_categories(ent_attrs)\n# => [\"http://aai.dfn.de/category/bwidm-member\",\n# \"http://eduid.cz/uri/idp-group/university\",\n# \"http://refeds.org/category/hide-from-discovery\",\n# \"http://refeds.org/category/research-and-scholarship\",\n# \"http://www.geant.net/uri/dataprotection-code-of-conduct/v1\",\n# \"https://edugate.heanet.ie/rr3/p/page/HEAnetInternalEC\",\n# \"https://federation.renater.fr/category/collaboratif\",\n# \"https://myacademicid.org/entity-categories/esi\",\n# \"https://refeds.org/category/anonymous\",\n# \"https://refeds.org/category/code-of-conduct/v2\",\n# \"https://refeds.org/category/hide-from-discovery\",\n# \"https://refeds.org/category/personalized\",\n# ... ]\n```","ref":"SmeeView.EntityAttributes.html#entity_categories/1"},{"type":"function","title":"SmeeView.EntityAttributes.hide?/1","doc":"Returns true if any of the attributes indicate Hide From Discovery status\n\n```\nSmeeView.EntityAttributes.hide?(ent_attrs)\n# => true\n```","ref":"SmeeView.EntityAttributes.html#hide?/1"},{"type":"function","title":"SmeeView.EntityAttributes.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nEntityAttributes.idp_filter(view)\n# => []\n```","ref":"SmeeView.EntityAttributes.html#idp_filter/1"},{"type":"function","title":"SmeeView.EntityAttributes.names/1","doc":"Returns a list of all attribute names.\n\nThe results are sorted and each value is unique.\n\n```\nSmeeView.EntityAttributes.names(ent_attrs)\n# => [\"http://kafe.kreonet.net/jurisdiction\", \"http://macedir.org/entity-category\",\n# \"http://macedir.org/entity-category-support\",\n# \"https://federation.renater.fr/member-of\",\n# \"urn:oasis:names:tc:SAML:attribute:assurance-certification\",\n# \"urn:oasis:names:tc:SAML:profiles:subject-id:req\",\n# \"urn:oid:2.16.756.1.2.5.1.1.4\", \"urn:oid:2.16.756.1.2.5.1.1.5\"]\n```","ref":"SmeeView.EntityAttributes.html#names/1"},{"type":"function","title":"SmeeView.EntityAttributes.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.EntityAttribute` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEntityAttributes.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.EntityAttribute{}, %Elixir.SmeeView.Aspects.EntityAttribute{},]}\n```","ref":"SmeeView.EntityAttributes.html#prism/3"},{"type":"function","title":"SmeeView.EntityAttributes.ras?/1","doc":"Returns true if any of the attributes indicate Research And Scholarship status\n\n```\nSmeeView.EntityAttributes.ras?(ent_attrs)\n# => true\n```","ref":"SmeeView.EntityAttributes.html#ras?/1"},{"type":"function","title":"SmeeView.EntityAttributes.required_subject_ids/1","doc":"Lists all nameid types marked as required with the `urn:oasis:names:tc:SAML:profiles:subject-id:req` attribute\n\n```\nSmeeView.EntityAttributes.required_subject_ids(ent_attrs)\n# => [\"pairwise-id\", \"subject-id\"]\n```","ref":"SmeeView.EntityAttributes.html#required_subject_ids/1"},{"type":"function","title":"SmeeView.EntityAttributes.sirtfi?/1","doc":"Returns true if any of the attributes indicate SIRTFI status\n\n```\nSmeeView.EntityAttributes.sirtfi?(ent_attrs)\n# => false\n```","ref":"SmeeView.EntityAttributes.html#sirtfi?/1"},{"type":"function","title":"SmeeView.EntityAttributes.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nEntityAttributes.sp_filter(view)\n# => []\n```","ref":"SmeeView.EntityAttributes.html#sp_filter/1"},{"type":"function","title":"SmeeView.EntityAttributes.supports?/2","doc":"Returns true if any of the attributes show support for the specified entity category\n\n```\nSmeeView.EntityAttributes.supports?(ent_attrs, \"https://refeds.org/category/anonymous\")\n# => false\n```","ref":"SmeeView.EntityAttributes.html#supports?/2"},{"type":"function","title":"SmeeView.EntityAttributes.supports_entity_categories/1","doc":"Lists all values for entity category support attributes (`http://macedir.org/entity-category-support`)\n\n```\nSmeeView.EntityAttributes.supports_entity_categories(ent_attrs)\n# => [\"http://clarin.eu/category/clarin-member\",\n# \"http://refeds.org/category/research-and-scholarship\",\n# \"http://www.geant.net/uri/dataprotection-code-of-conduct/v1\",\n# \"https://idp.lit.ie/saml2\", \"https://login.dcu.ie\",\n# \"https://myacademicid.org/entity-categories/esi\",\n# \"https://refeds.org/category/anonymous\",\n# \"https://refeds.org/category/code-of-conduct/v2\",\n# \"https://refeds.org/category/personalized\", \"https://refeds.org/sirtfi\"]\n```","ref":"SmeeView.EntityAttributes.html#supports_entity_categories/1"},{"type":"function","title":"SmeeView.EntityAttributes.values/1","doc":"Returns a list of all attribute values - every value for every attribute.\n\nThe results are sorted and each value is unique.\n\n```\nSmeeView.EntityAttributes.values(ent_attrs)\n# => [\"KR\", \"any\", \"hospital\",  \"http://aai.dfn.de/category/bwidm-member\",\n# \"http://aai.dfn.de/category/campus-lsa-member\",\n# \"http://clarin.eu/category/clarin-member\", \"http://eduid.cz/uri/group/mefanet\",\n# \"http://refeds.org/category/hide-from-discovery\",\n# \"http://refeds.org/category/research-and-scholarship\", ...]\n```","ref":"SmeeView.EntityAttributes.html#values/1"},{"type":"function","title":"SmeeView.EntityAttributes.values_for/2","doc":"Lists all attribute values for the specified attribute name\n\nThe results are sorted and each value is unique.\n\n```\nSmeeView.EntityAttributes.values_for(ent_attrs, \"urn:oasis:names:tc:SAML:attribute:assurance-certification\")\n# => [\"http://refeds.org/sirtfi\", \"http://www.swamid.se/policy/assurance/al1\",\n# \"https://refeds.org/sirtfi\", \"https://refeds.org/sirtfi2\"]\n```","ref":"SmeeView.EntityAttributes.html#values_for/2"},{"type":"function","title":"SmeeView.EntityAttributes.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.EntityAttribute` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEntityAttributes.view(entity)\n# => [%Elixir.SmeeView.Aspects.EntityAttribute{}, %Elixir.SmeeView.Aspects.EntityAttribute{}]\n```","ref":"SmeeView.EntityAttributes.html#view/3"},{"type":"function","title":"SmeeView.EntityAttributes.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.EntityAttribute` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nEntityAttributes.view_one(entity)\n# => %Elixir.SmeeView.Aspects.EntityAttribute{}\n```","ref":"SmeeView.EntityAttributes.html#view_one/3"},{"type":"module","title":"SmeeView.Geolocations","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Geolocations.html"},{"type":"function","title":"SmeeView.Geolocations.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nGeolocations.idp_filter(view)\n# => []\n```","ref":"SmeeView.Geolocations.html#idp_filter/1"},{"type":"function","title":"SmeeView.Geolocations.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Geolocation` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nGeolocations.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Geolocation{}, %Elixir.SmeeView.Aspects.Geolocation{},]}\n```","ref":"SmeeView.Geolocations.html#prism/3"},{"type":"function","title":"SmeeView.Geolocations.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nGeolocations.sp_filter(view)\n# => []\n```","ref":"SmeeView.Geolocations.html#sp_filter/1"},{"type":"function","title":"SmeeView.Geolocations.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Geolocation` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nGeolocations.view(entity)\n# => [%Elixir.SmeeView.Aspects.Geolocation{}, %Elixir.SmeeView.Aspects.Geolocation{}]\n```","ref":"SmeeView.Geolocations.html#view/3"},{"type":"function","title":"SmeeView.Geolocations.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Geolocation` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nGeolocations.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Geolocation{}\n```","ref":"SmeeView.Geolocations.html#view_one/3"},{"type":"module","title":"SmeeView.IdPs","doc":"This module can extracts a bundle of aspects from the IdP role in a SAML entity's metadata.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.IdPs.html"},{"type":"function","title":"SmeeView.IdPs.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nIdPs.idp_filter(view)\n# => []\n```","ref":"SmeeView.IdPs.html#idp_filter/1"},{"type":"function","title":"SmeeView.IdPs.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.IdP` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nIdPs.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.IdP{}, %Elixir.SmeeView.Aspects.IdP{},]}\n```","ref":"SmeeView.IdPs.html#prism/3"},{"type":"function","title":"SmeeView.IdPs.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nIdPs.sp_filter(view)\n# => []\n```","ref":"SmeeView.IdPs.html#sp_filter/1"},{"type":"function","title":"SmeeView.IdPs.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.IdP` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nIdPs.view(entity)\n# => [%Elixir.SmeeView.Aspects.IdP{}, %Elixir.SmeeView.Aspects.IdP{}]\n```","ref":"SmeeView.IdPs.html#view/3"},{"type":"function","title":"SmeeView.IdPs.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.IdP` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nIdPs.view_one(entity)\n# => %Elixir.SmeeView.Aspects.IdP{}\n```","ref":"SmeeView.IdPs.html#view_one/3"},{"type":"module","title":"SmeeView.InformationURLs","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.InformationURLs.html"},{"type":"function","title":"SmeeView.InformationURLs.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nInformationURLs.idp_filter(view)\n# => []\n```","ref":"SmeeView.InformationURLs.html#idp_filter/1"},{"type":"function","title":"SmeeView.InformationURLs.langs/1","doc":"Returns all languages used in the list (view) or map (prism)\n\n```\nInformationURLs.langs(aspects)\n# => [\"en\", \"se\", \"zu\"]\n```","ref":"SmeeView.InformationURLs.html#langs/1"},{"type":"function","title":"SmeeView.InformationURLs.pick/2","doc":"Returns the first aspect with matching language, or failing that, the default language, or English\n\nThis function is useful when showing a UI to users, to select the most appropriate aspect for display\n\n```\nInformationURLs.pick(aspects, \"no\")\n# => %Elixir.SmeeView.Aspects.InformationURL{lang: \"no\" text: \"...\" }\n```","ref":"SmeeView.InformationURLs.html#pick/2"},{"type":"function","title":"SmeeView.InformationURLs.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.InformationURL` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nInformationURLs.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.InformationURL{}, %Elixir.SmeeView.Aspects.InformationURL{},]}\n```","ref":"SmeeView.InformationURLs.html#prism/3"},{"type":"function","title":"SmeeView.InformationURLs.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nInformationURLs.sp_filter(view)\n# => []\n```","ref":"SmeeView.InformationURLs.html#sp_filter/1"},{"type":"function","title":"SmeeView.InformationURLs.valid_filter/1","doc":"Returns filtered list of only valid URLs from a view (list) or prism (map)\n\nIt's unlikely that invalid URLs will be in NREN metadata, but this may be useful when producing your own.\n\n```\nInformationURLs.valid_filter(aspects)\n# => [%Elixir.SmeeView.Aspects.InformationURL{}]\n```","ref":"SmeeView.InformationURLs.html#valid_filter/1"},{"type":"function","title":"SmeeView.InformationURLs.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.InformationURL` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nInformationURLs.view(entity)\n# => [%Elixir.SmeeView.Aspects.InformationURL{}, %Elixir.SmeeView.Aspects.InformationURL{}]\n```","ref":"SmeeView.InformationURLs.html#view/3"},{"type":"function","title":"SmeeView.InformationURLs.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.InformationURL` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nInformationURLs.view_one(entity)\n# => %Elixir.SmeeView.Aspects.InformationURL{}\n```","ref":"SmeeView.InformationURLs.html#view_one/3"},{"type":"module","title":"SmeeView.Keys","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Keys.html"},{"type":"function","title":"SmeeView.Keys.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nKeys.idp_filter(view)\n# => []\n```","ref":"SmeeView.Keys.html#idp_filter/1"},{"type":"function","title":"SmeeView.Keys.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Key` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nKeys.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Key{}, %Elixir.SmeeView.Aspects.Key{},]}\n```","ref":"SmeeView.Keys.html#prism/3"},{"type":"function","title":"SmeeView.Keys.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nKeys.sp_filter(view)\n# => []\n```","ref":"SmeeView.Keys.html#sp_filter/1"},{"type":"function","title":"SmeeView.Keys.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Key` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nKeys.view(entity)\n# => [%Elixir.SmeeView.Aspects.Key{}, %Elixir.SmeeView.Aspects.Key{}]\n```","ref":"SmeeView.Keys.html#view/3"},{"type":"function","title":"SmeeView.Keys.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Key` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nKeys.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Key{}\n```","ref":"SmeeView.Keys.html#view_one/3"},{"type":"module","title":"SmeeView.Keywords","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Keywords.html"},{"type":"function","title":"SmeeView.Keywords.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nKeywords.idp_filter(view)\n# => []\n```","ref":"SmeeView.Keywords.html#idp_filter/1"},{"type":"function","title":"SmeeView.Keywords.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Keywords` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nKeywords.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Keywords{}, %Elixir.SmeeView.Aspects.Keywords{},]}\n```","ref":"SmeeView.Keywords.html#prism/3"},{"type":"function","title":"SmeeView.Keywords.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nKeywords.sp_filter(view)\n# => []\n```","ref":"SmeeView.Keywords.html#sp_filter/1"},{"type":"function","title":"SmeeView.Keywords.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Keywords` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nKeywords.view(entity)\n# => [%Elixir.SmeeView.Aspects.Keywords{}, %Elixir.SmeeView.Aspects.Keywords{}]\n```","ref":"SmeeView.Keywords.html#view/3"},{"type":"function","title":"SmeeView.Keywords.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Keywords` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nKeywords.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Keywords{}\n```","ref":"SmeeView.Keywords.html#view_one/3"},{"type":"module","title":"SmeeView.Logos","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Logos.html"},{"type":"function","title":"SmeeView.Logos.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nLogos.idp_filter(view)\n# => []\n```","ref":"SmeeView.Logos.html#idp_filter/1"},{"type":"function","title":"SmeeView.Logos.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Logo` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nLogos.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Logo{}, %Elixir.SmeeView.Aspects.Logo{},]}\n```","ref":"SmeeView.Logos.html#prism/3"},{"type":"function","title":"SmeeView.Logos.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nLogos.sp_filter(view)\n# => []\n```","ref":"SmeeView.Logos.html#sp_filter/1"},{"type":"function","title":"SmeeView.Logos.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Logo` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nLogos.view(entity)\n# => [%Elixir.SmeeView.Aspects.Logo{}, %Elixir.SmeeView.Aspects.Logo{}]\n```","ref":"SmeeView.Logos.html#view/3"},{"type":"function","title":"SmeeView.Logos.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Logo` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nLogos.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Logo{}\n```","ref":"SmeeView.Logos.html#view_one/3"},{"type":"module","title":"SmeeView.ManageNameidServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.ManageNameidServices.html"},{"type":"function","title":"SmeeView.ManageNameidServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nManageNameidServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.ManageNameidServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.ManageNameidServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nManageNameidServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.ManageNameidServices.html#bindings/1"},{"type":"function","title":"SmeeView.ManageNameidServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nManageNameidServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.ManageNameidServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.ManageNameidServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.ManageNameidService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nManageNameidServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.ManageNameidService{}, %Elixir.SmeeView.Aspects.ManageNameidService{},]}\n```","ref":"SmeeView.ManageNameidServices.html#prism/3"},{"type":"function","title":"SmeeView.ManageNameidServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nManageNameidServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.ManageNameidServices.html#sort/1"},{"type":"function","title":"SmeeView.ManageNameidServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nManageNameidServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.ManageNameidServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.ManageNameidServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.ManageNameidService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nManageNameidServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.ManageNameidService{}, %Elixir.SmeeView.Aspects.ManageNameidService{}]\n```","ref":"SmeeView.ManageNameidServices.html#view/3"},{"type":"function","title":"SmeeView.ManageNameidServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.ManageNameidService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nManageNameidServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.ManageNameidService{}\n```","ref":"SmeeView.ManageNameidServices.html#view_one/3"},{"type":"module","title":"SmeeView.NameIDFormats","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.NameIDFormats.html"},{"type":"function","title":"SmeeView.NameIDFormats.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nNameIDFormats.idp_filter(view)\n# => []\n```","ref":"SmeeView.NameIDFormats.html#idp_filter/1"},{"type":"function","title":"SmeeView.NameIDFormats.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.NameIDFormat` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNameIDFormats.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.NameIDFormat{}, %Elixir.SmeeView.Aspects.NameIDFormat{},]}\n```","ref":"SmeeView.NameIDFormats.html#prism/3"},{"type":"function","title":"SmeeView.NameIDFormats.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nNameIDFormats.sp_filter(view)\n# => []\n```","ref":"SmeeView.NameIDFormats.html#sp_filter/1"},{"type":"function","title":"SmeeView.NameIDFormats.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.NameIDFormat` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNameIDFormats.view(entity)\n# => [%Elixir.SmeeView.Aspects.NameIDFormat{}, %Elixir.SmeeView.Aspects.NameIDFormat{}]\n```","ref":"SmeeView.NameIDFormats.html#view/3"},{"type":"function","title":"SmeeView.NameIDFormats.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.NameIDFormat` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNameIDFormats.view_one(entity)\n# => %Elixir.SmeeView.Aspects.NameIDFormat{}\n```","ref":"SmeeView.NameIDFormats.html#view_one/3"},{"type":"module","title":"SmeeView.NameidMappingServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.NameidMappingServices.html"},{"type":"function","title":"SmeeView.NameidMappingServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nNameidMappingServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.NameidMappingServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.NameidMappingServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nNameidMappingServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.NameidMappingServices.html#bindings/1"},{"type":"function","title":"SmeeView.NameidMappingServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nNameidMappingServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.NameidMappingServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.NameidMappingServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.NameidMappingService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNameidMappingServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.NameidMappingService{}, %Elixir.SmeeView.Aspects.NameidMappingService{},]}\n```","ref":"SmeeView.NameidMappingServices.html#prism/3"},{"type":"function","title":"SmeeView.NameidMappingServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nNameidMappingServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.NameidMappingServices.html#sort/1"},{"type":"function","title":"SmeeView.NameidMappingServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nNameidMappingServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.NameidMappingServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.NameidMappingServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.NameidMappingService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNameidMappingServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.NameidMappingService{}, %Elixir.SmeeView.Aspects.NameidMappingService{}]\n```","ref":"SmeeView.NameidMappingServices.html#view/3"},{"type":"function","title":"SmeeView.NameidMappingServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.NameidMappingService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNameidMappingServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.NameidMappingService{}\n```","ref":"SmeeView.NameidMappingServices.html#view_one/3"},{"type":"module","title":"SmeeView.Networks","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Networks.html"},{"type":"function","title":"SmeeView.Networks.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nNetworks.idp_filter(view)\n# => []\n```","ref":"SmeeView.Networks.html#idp_filter/1"},{"type":"function","title":"SmeeView.Networks.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Network` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNetworks.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Network{}, %Elixir.SmeeView.Aspects.Network{},]}\n```","ref":"SmeeView.Networks.html#prism/3"},{"type":"function","title":"SmeeView.Networks.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nNetworks.sp_filter(view)\n# => []\n```","ref":"SmeeView.Networks.html#sp_filter/1"},{"type":"function","title":"SmeeView.Networks.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Network` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNetworks.view(entity)\n# => [%Elixir.SmeeView.Aspects.Network{}, %Elixir.SmeeView.Aspects.Network{}]\n```","ref":"SmeeView.Networks.html#view/3"},{"type":"function","title":"SmeeView.Networks.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Network` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nNetworks.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Network{}\n```","ref":"SmeeView.Networks.html#view_one/3"},{"type":"module","title":"SmeeView.OrganizationDisplaynames","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.OrganizationDisplaynames.html"},{"type":"function","title":"SmeeView.OrganizationDisplaynames.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nOrganizationDisplaynames.idp_filter(view)\n# => []\n```","ref":"SmeeView.OrganizationDisplaynames.html#idp_filter/1"},{"type":"function","title":"SmeeView.OrganizationDisplaynames.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.OrganizationDisplayname` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationDisplaynames.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.OrganizationDisplayname{}, %Elixir.SmeeView.Aspects.OrganizationDisplayname{},]}\n```","ref":"SmeeView.OrganizationDisplaynames.html#prism/3"},{"type":"function","title":"SmeeView.OrganizationDisplaynames.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nOrganizationDisplaynames.sp_filter(view)\n# => []\n```","ref":"SmeeView.OrganizationDisplaynames.html#sp_filter/1"},{"type":"function","title":"SmeeView.OrganizationDisplaynames.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.OrganizationDisplayname` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationDisplaynames.view(entity)\n# => [%Elixir.SmeeView.Aspects.OrganizationDisplayname{}, %Elixir.SmeeView.Aspects.OrganizationDisplayname{}]\n```","ref":"SmeeView.OrganizationDisplaynames.html#view/3"},{"type":"function","title":"SmeeView.OrganizationDisplaynames.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.OrganizationDisplayname` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationDisplaynames.view_one(entity)\n# => %Elixir.SmeeView.Aspects.OrganizationDisplayname{}\n```","ref":"SmeeView.OrganizationDisplaynames.html#view_one/3"},{"type":"module","title":"SmeeView.OrganizationNames","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.OrganizationNames.html"},{"type":"function","title":"SmeeView.OrganizationNames.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nOrganizationNames.idp_filter(view)\n# => []\n```","ref":"SmeeView.OrganizationNames.html#idp_filter/1"},{"type":"function","title":"SmeeView.OrganizationNames.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.OrganizationName` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationNames.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.OrganizationName{}, %Elixir.SmeeView.Aspects.OrganizationName{},]}\n```","ref":"SmeeView.OrganizationNames.html#prism/3"},{"type":"function","title":"SmeeView.OrganizationNames.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nOrganizationNames.sp_filter(view)\n# => []\n```","ref":"SmeeView.OrganizationNames.html#sp_filter/1"},{"type":"function","title":"SmeeView.OrganizationNames.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.OrganizationName` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationNames.view(entity)\n# => [%Elixir.SmeeView.Aspects.OrganizationName{}, %Elixir.SmeeView.Aspects.OrganizationName{}]\n```","ref":"SmeeView.OrganizationNames.html#view/3"},{"type":"function","title":"SmeeView.OrganizationNames.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.OrganizationName` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationNames.view_one(entity)\n# => %Elixir.SmeeView.Aspects.OrganizationName{}\n```","ref":"SmeeView.OrganizationNames.html#view_one/3"},{"type":"module","title":"SmeeView.OrganizationURLs","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.OrganizationURLs.html"},{"type":"function","title":"SmeeView.OrganizationURLs.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nOrganizationURLs.idp_filter(view)\n# => []\n```","ref":"SmeeView.OrganizationURLs.html#idp_filter/1"},{"type":"function","title":"SmeeView.OrganizationURLs.langs/1","doc":"Returns all languages used in the list (view) or map (prism)\n\n```\nOrganizationURLs.langs(aspects)\n# => [\"en\", \"se\", \"zu\"]\n```","ref":"SmeeView.OrganizationURLs.html#langs/1"},{"type":"function","title":"SmeeView.OrganizationURLs.pick/2","doc":"Returns the first aspect with matching language, or failing that, the default language, or English\n\nThis function is useful when showing a UI to users, to select the most appropriate aspect for display\n\n```\nOrganizationURLs.pick(aspects, \"no\")\n# => %Elixir.SmeeView.Aspects.OrganizationURL{lang: \"no\" text: \"...\" }\n```","ref":"SmeeView.OrganizationURLs.html#pick/2"},{"type":"function","title":"SmeeView.OrganizationURLs.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.OrganizationURL` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationURLs.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.OrganizationURL{}, %Elixir.SmeeView.Aspects.OrganizationURL{},]}\n```","ref":"SmeeView.OrganizationURLs.html#prism/3"},{"type":"function","title":"SmeeView.OrganizationURLs.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nOrganizationURLs.sp_filter(view)\n# => []\n```","ref":"SmeeView.OrganizationURLs.html#sp_filter/1"},{"type":"function","title":"SmeeView.OrganizationURLs.valid_filter/1","doc":"Returns filtered list of only valid URLs from a view (list) or prism (map)\n\nIt's unlikely that invalid URLs will be in NREN metadata, but this may be useful when producing your own.\n\n```\nOrganizationURLs.valid_filter(aspects)\n# => [%Elixir.SmeeView.Aspects.OrganizationURL{}]\n```","ref":"SmeeView.OrganizationURLs.html#valid_filter/1"},{"type":"function","title":"SmeeView.OrganizationURLs.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.OrganizationURL` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationURLs.view(entity)\n# => [%Elixir.SmeeView.Aspects.OrganizationURL{}, %Elixir.SmeeView.Aspects.OrganizationURL{}]\n```","ref":"SmeeView.OrganizationURLs.html#view/3"},{"type":"function","title":"SmeeView.OrganizationURLs.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.OrganizationURL` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizationURLs.view_one(entity)\n# => %Elixir.SmeeView.Aspects.OrganizationURL{}\n```","ref":"SmeeView.OrganizationURLs.html#view_one/3"},{"type":"module","title":"SmeeView.Organizations","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Organizations.html"},{"type":"function","title":"SmeeView.Organizations.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nOrganizations.idp_filter(view)\n# => []\n```","ref":"SmeeView.Organizations.html#idp_filter/1"},{"type":"function","title":"SmeeView.Organizations.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Organization` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizations.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Organization{}, %Elixir.SmeeView.Aspects.Organization{},]}\n```","ref":"SmeeView.Organizations.html#prism/3"},{"type":"function","title":"SmeeView.Organizations.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nOrganizations.sp_filter(view)\n# => []\n```","ref":"SmeeView.Organizations.html#sp_filter/1"},{"type":"function","title":"SmeeView.Organizations.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Organization` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizations.view(entity)\n# => [%Elixir.SmeeView.Aspects.Organization{}, %Elixir.SmeeView.Aspects.Organization{}]\n```","ref":"SmeeView.Organizations.html#view/3"},{"type":"function","title":"SmeeView.Organizations.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Organization` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nOrganizations.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Organization{}\n```","ref":"SmeeView.Organizations.html#view_one/3"},{"type":"module","title":"SmeeView.PrivacyURLs","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.PrivacyURLs.html"},{"type":"function","title":"SmeeView.PrivacyURLs.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nPrivacyURLs.idp_filter(view)\n# => []\n```","ref":"SmeeView.PrivacyURLs.html#idp_filter/1"},{"type":"function","title":"SmeeView.PrivacyURLs.langs/1","doc":"Returns all languages used in the list (view) or map (prism)\n\n```\nPrivacyURLs.langs(aspects)\n# => [\"en\", \"se\", \"zu\"]\n```","ref":"SmeeView.PrivacyURLs.html#langs/1"},{"type":"function","title":"SmeeView.PrivacyURLs.pick/2","doc":"Returns the first aspect with matching language, or failing that, the default language, or English\n\nThis function is useful when showing a UI to users, to select the most appropriate aspect for display\n\n```\nPrivacyURLs.pick(aspects, \"no\")\n# => %Elixir.SmeeView.Aspects.PrivacyURL{lang: \"no\" text: \"...\" }\n```","ref":"SmeeView.PrivacyURLs.html#pick/2"},{"type":"function","title":"SmeeView.PrivacyURLs.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.PrivacyURL` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nPrivacyURLs.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.PrivacyURL{}, %Elixir.SmeeView.Aspects.PrivacyURL{},]}\n```","ref":"SmeeView.PrivacyURLs.html#prism/3"},{"type":"function","title":"SmeeView.PrivacyURLs.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nPrivacyURLs.sp_filter(view)\n# => []\n```","ref":"SmeeView.PrivacyURLs.html#sp_filter/1"},{"type":"function","title":"SmeeView.PrivacyURLs.valid_filter/1","doc":"Returns filtered list of only valid URLs from a view (list) or prism (map)\n\nIt's unlikely that invalid URLs will be in NREN metadata, but this may be useful when producing your own.\n\n```\nPrivacyURLs.valid_filter(aspects)\n# => [%Elixir.SmeeView.Aspects.PrivacyURL{}]\n```","ref":"SmeeView.PrivacyURLs.html#valid_filter/1"},{"type":"function","title":"SmeeView.PrivacyURLs.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.PrivacyURL` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nPrivacyURLs.view(entity)\n# => [%Elixir.SmeeView.Aspects.PrivacyURL{}, %Elixir.SmeeView.Aspects.PrivacyURL{}]\n```","ref":"SmeeView.PrivacyURLs.html#view/3"},{"type":"function","title":"SmeeView.PrivacyURLs.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.PrivacyURL` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nPrivacyURLs.view_one(entity)\n# => %Elixir.SmeeView.Aspects.PrivacyURL{}\n```","ref":"SmeeView.PrivacyURLs.html#view_one/3"},{"type":"module","title":"SmeeView.Protocols","doc":"This module can extracts the `protocolSupportEnumeration` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Protocols.html"},{"type":"function","title":"SmeeView.Protocols.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nProtocols.idp_filter(view)\n# => []\n```","ref":"SmeeView.Protocols.html#idp_filter/1"},{"type":"function","title":"SmeeView.Protocols.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Protocol` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nProtocols.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Protocol{}, %Elixir.SmeeView.Aspects.Protocol{},]}\n```","ref":"SmeeView.Protocols.html#prism/3"},{"type":"function","title":"SmeeView.Protocols.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nProtocols.sp_filter(view)\n# => []\n```","ref":"SmeeView.Protocols.html#sp_filter/1"},{"type":"function","title":"SmeeView.Protocols.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Protocol` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nProtocols.view(entity)\n# => [%Elixir.SmeeView.Aspects.Protocol{}, %Elixir.SmeeView.Aspects.Protocol{}]\n```","ref":"SmeeView.Protocols.html#view/3"},{"type":"function","title":"SmeeView.Protocols.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Protocol` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nProtocols.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Protocol{}\n```","ref":"SmeeView.Protocols.html#view_one/3"},{"type":"module","title":"SmeeView.PublicationPath","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.PublicationPath.html"},{"type":"function","title":"SmeeView.PublicationPath.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nPublicationPath.idp_filter(view)\n# => []\n```","ref":"SmeeView.PublicationPath.html#idp_filter/1"},{"type":"function","title":"SmeeView.PublicationPath.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Publication` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nPublicationPath.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Publication{}, %Elixir.SmeeView.Aspects.Publication{},]}\n```","ref":"SmeeView.PublicationPath.html#prism/3"},{"type":"function","title":"SmeeView.PublicationPath.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nPublicationPath.sp_filter(view)\n# => []\n```","ref":"SmeeView.PublicationPath.html#sp_filter/1"},{"type":"function","title":"SmeeView.PublicationPath.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Publication` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nPublicationPath.view(entity)\n# => [%Elixir.SmeeView.Aspects.Publication{}, %Elixir.SmeeView.Aspects.Publication{}]\n```","ref":"SmeeView.PublicationPath.html#view/3"},{"type":"function","title":"SmeeView.PublicationPath.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Publication` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nPublicationPath.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Publication{}\n```","ref":"SmeeView.PublicationPath.html#view_one/3"},{"type":"module","title":"SmeeView.Registration","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.\n\n* [SAML V2.0 Metadata Extensions for Registration and Publication Information](http://docs.oasis-open.org/security/saml/Post2.0/saml-metadata-rpi/v1.0/cs01/saml-metadata-rpi-v1.0-cs01.html)","ref":"SmeeView.Registration.html"},{"type":"function","title":"SmeeView.Registration.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nRegistration.idp_filter(view)\n# => []\n```","ref":"SmeeView.Registration.html#idp_filter/1"},{"type":"function","title":"SmeeView.Registration.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Registration` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRegistration.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Registration{}, %Elixir.SmeeView.Aspects.Registration{},]}\n```","ref":"SmeeView.Registration.html#prism/3"},{"type":"function","title":"SmeeView.Registration.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nRegistration.sp_filter(view)\n# => []\n```","ref":"SmeeView.Registration.html#sp_filter/1"},{"type":"function","title":"SmeeView.Registration.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Registration` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRegistration.view(entity)\n# => [%Elixir.SmeeView.Aspects.Registration{}, %Elixir.SmeeView.Aspects.Registration{}]\n```","ref":"SmeeView.Registration.html#view/3"},{"type":"function","title":"SmeeView.Registration.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Registration` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRegistration.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Registration{}\n```","ref":"SmeeView.Registration.html#view_one/3"},{"type":"module","title":"SmeeView.RegistrationPolicies","doc":"This module can extracts the `< ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.\n\n* [SAML V2.0 Metadata Extensions for Registration and Publication Information](http://docs.oasis-open.org/security/saml/Post2.0/saml-metadata-rpi/v1.0/cs01/saml-metadata-rpi-v1.0-cs01.html)","ref":"SmeeView.RegistrationPolicies.html"},{"type":"function","title":"SmeeView.RegistrationPolicies.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nRegistrationPolicies.idp_filter(view)\n# => []\n```","ref":"SmeeView.RegistrationPolicies.html#idp_filter/1"},{"type":"function","title":"SmeeView.RegistrationPolicies.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.RegistrationPolicy` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRegistrationPolicies.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.RegistrationPolicy{}, %Elixir.SmeeView.Aspects.RegistrationPolicy{},]}\n```","ref":"SmeeView.RegistrationPolicies.html#prism/3"},{"type":"function","title":"SmeeView.RegistrationPolicies.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nRegistrationPolicies.sp_filter(view)\n# => []\n```","ref":"SmeeView.RegistrationPolicies.html#sp_filter/1"},{"type":"function","title":"SmeeView.RegistrationPolicies.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.RegistrationPolicy` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRegistrationPolicies.view(entity)\n# => [%Elixir.SmeeView.Aspects.RegistrationPolicy{}, %Elixir.SmeeView.Aspects.RegistrationPolicy{}]\n```","ref":"SmeeView.RegistrationPolicies.html#view/3"},{"type":"function","title":"SmeeView.RegistrationPolicies.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.RegistrationPolicy` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRegistrationPolicies.view_one(entity)\n# => %Elixir.SmeeView.Aspects.RegistrationPolicy{}\n```","ref":"SmeeView.RegistrationPolicies.html#view_one/3"},{"type":"module","title":"SmeeView.RequestInitiators","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.RequestInitiators.html"},{"type":"function","title":"SmeeView.RequestInitiators.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nRequestInitiators.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.RequestInitiators.html#binding_filter/2"},{"type":"function","title":"SmeeView.RequestInitiators.bindings/1","doc":"Returns all bindings present in the view\n\n```\nRequestInitiators.bindings(aspects)\n# => []\n```","ref":"SmeeView.RequestInitiators.html#bindings/1"},{"type":"function","title":"SmeeView.RequestInitiators.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nRequestInitiators.idp_filter(view)\n# => []\n```","ref":"SmeeView.RequestInitiators.html#idp_filter/1"},{"type":"function","title":"SmeeView.RequestInitiators.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.RequestInitiator` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRequestInitiators.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.RequestInitiator{}, %Elixir.SmeeView.Aspects.RequestInitiator{},]}\n```","ref":"SmeeView.RequestInitiators.html#prism/3"},{"type":"function","title":"SmeeView.RequestInitiators.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nRequestInitiators.sort(aspect)\n# => [...]\n```","ref":"SmeeView.RequestInitiators.html#sort/1"},{"type":"function","title":"SmeeView.RequestInitiators.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nRequestInitiators.sp_filter(view)\n# => []\n```","ref":"SmeeView.RequestInitiators.html#sp_filter/1"},{"type":"function","title":"SmeeView.RequestInitiators.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.RequestInitiator` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRequestInitiators.view(entity)\n# => [%Elixir.SmeeView.Aspects.RequestInitiator{}, %Elixir.SmeeView.Aspects.RequestInitiator{}]\n```","ref":"SmeeView.RequestInitiators.html#view/3"},{"type":"function","title":"SmeeView.RequestInitiators.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.RequestInitiator` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRequestInitiators.view_one(entity)\n# => %Elixir.SmeeView.Aspects.RequestInitiator{}\n```","ref":"SmeeView.RequestInitiators.html#view_one/3"},{"type":"module","title":"SmeeView.RequestedAttributes","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.RequestedAttributes.html"},{"type":"function","title":"SmeeView.RequestedAttributes.contain?/2","doc":"Returns true if the aspects contain the specified attribute name\n\n```\n  RequestedAttributes.contain?(attrs, \"urn:oid:1.3.6.1.4.1.5923.1.1.1.6\")\n# => true\n\n\n```","ref":"SmeeView.RequestedAttributes.html#contain?/2"},{"type":"function","title":"SmeeView.RequestedAttributes.contain_friendly?/2","doc":"Returns true if the aspects contain the specified attribute friendly name\n\n```\n  RequestedAttributes.contain?(attrs, \"sn\")\n# => true\n\n\n```","ref":"SmeeView.RequestedAttributes.html#contain_friendly?/2"},{"type":"function","title":"SmeeView.RequestedAttributes.friendly_names/1","doc":"Returns a list of all attribute names (full, technical, URI names).\n\nThe results are sorted and each value is unique.\n\n```\n  RequestedAttributes.friendly_names(attrs)\n# => [\"eduPersonPrincipalName\", \"email\", \"organizationName\"]\n```","ref":"SmeeView.RequestedAttributes.html#friendly_names/1"},{"type":"function","title":"SmeeView.RequestedAttributes.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nRequestedAttributes.idp_filter(view)\n# => []\n```","ref":"SmeeView.RequestedAttributes.html#idp_filter/1"},{"type":"function","title":"SmeeView.RequestedAttributes.names/1","doc":"Returns a list of all attribute names (full, technical, URI names).\n\nThe results are sorted and each value is unique.\n\n```\n  RequestedAttributes.names(attrs)\n# => [\"urn:oid:1.3.6.1.4.1.5923.1.1.1.6\", \"urn:oid:0.9.2342.19200300.100.1.3\", \"urn:oid:2.5.4.10\"]\n```","ref":"SmeeView.RequestedAttributes.html#names/1"},{"type":"function","title":"SmeeView.RequestedAttributes.optional_filter/1","doc":"Returns only optional attributes\n\nFilters the view (list) or prism (map) to only include required attributes\n\n```\nSmeeView.RequestedAttributes.optional_filter(aspects)\n# =>  [%SmeeView.Aspect.RequestedAttribute{}, %SmeeView.Aspect.RequestedAttribute{}]\n```","ref":"SmeeView.RequestedAttributes.html#optional_filter/1"},{"type":"function","title":"SmeeView.RequestedAttributes.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.RequestedAttribute` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRequestedAttributes.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.RequestedAttribute{}, %Elixir.SmeeView.Aspects.RequestedAttribute{},]}\n```","ref":"SmeeView.RequestedAttributes.html#prism/3"},{"type":"function","title":"SmeeView.RequestedAttributes.required_filter/1","doc":"Returns only required attributes\n\nFilters the view (list) or prism (map) to only include required attributes\n\n```\nSmeeView.RequestedAttributes.required_filter(aspects)\n# =>  [%SmeeView.Aspect.RequestedAttribute{}, %SmeeView.Aspect.RequestedAttribute{}]\n```","ref":"SmeeView.RequestedAttributes.html#required_filter/1"},{"type":"function","title":"SmeeView.RequestedAttributes.saml1_filter/1","doc":"Returns only SAML1 attributes\n\nFilters the view (list) or prism (map) to only include SAML1 attributes\n\n```\nRequestedAttributes.saml1_filter(aspects)\n# =>  [%Elixir.SmeeView.Aspects.RequestedAttribute{}]\n```","ref":"SmeeView.RequestedAttributes.html#saml1_filter/1"},{"type":"function","title":"SmeeView.RequestedAttributes.saml2_filter/1","doc":"Returns only SAML2 attributes\n\nFilters the view (list) or prism (map) to only include SAML2 attributes\n\n```\nRequestedAttributes.saml2_filter(aspects)\n# => [%Elixir.SmeeView.Aspects.RequestedAttribute{}]\n```","ref":"SmeeView.RequestedAttributes.html#saml2_filter/1"},{"type":"function","title":"SmeeView.RequestedAttributes.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nRequestedAttributes.sp_filter(view)\n# => []\n```","ref":"SmeeView.RequestedAttributes.html#sp_filter/1"},{"type":"function","title":"SmeeView.RequestedAttributes.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.RequestedAttribute` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRequestedAttributes.view(entity)\n# => [%Elixir.SmeeView.Aspects.RequestedAttribute{}, %Elixir.SmeeView.Aspects.RequestedAttribute{}]\n```","ref":"SmeeView.RequestedAttributes.html#view/3"},{"type":"function","title":"SmeeView.RequestedAttributes.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.RequestedAttribute` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nRequestedAttributes.view_one(entity)\n# => %Elixir.SmeeView.Aspects.RequestedAttribute{}\n```","ref":"SmeeView.RequestedAttributes.html#view_one/3"},{"type":"module","title":"SmeeView.SPs","doc":"This module can extracts a bundle of aspects from the IdP role in a SAML entity's metadata.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.SPs.html"},{"type":"function","title":"SmeeView.SPs.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nSPs.idp_filter(view)\n# => []\n```","ref":"SmeeView.SPs.html#idp_filter/1"},{"type":"function","title":"SmeeView.SPs.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.SP` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSPs.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.SP{}, %Elixir.SmeeView.Aspects.SP{},]}\n```","ref":"SmeeView.SPs.html#prism/3"},{"type":"function","title":"SmeeView.SPs.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nSPs.sp_filter(view)\n# => []\n```","ref":"SmeeView.SPs.html#sp_filter/1"},{"type":"function","title":"SmeeView.SPs.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.SP` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSPs.view(entity)\n# => [%Elixir.SmeeView.Aspects.SP{}, %Elixir.SmeeView.Aspects.SP{}]\n```","ref":"SmeeView.SPs.html#view/3"},{"type":"function","title":"SmeeView.SPs.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.SP` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSPs.view_one(entity)\n# => %Elixir.SmeeView.Aspects.SP{}\n```","ref":"SmeeView.SPs.html#view_one/3"},{"type":"module","title":"SmeeView.Scopes","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.Scopes.html"},{"type":"function","title":"SmeeView.Scopes.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nScopes.idp_filter(view)\n# => []\n```","ref":"SmeeView.Scopes.html#idp_filter/1"},{"type":"function","title":"SmeeView.Scopes.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.Scope` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nScopes.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.Scope{}, %Elixir.SmeeView.Aspects.Scope{},]}\n```","ref":"SmeeView.Scopes.html#prism/3"},{"type":"function","title":"SmeeView.Scopes.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nScopes.sp_filter(view)\n# => []\n```","ref":"SmeeView.Scopes.html#sp_filter/1"},{"type":"function","title":"SmeeView.Scopes.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.Scope` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nScopes.view(entity)\n# => [%Elixir.SmeeView.Aspects.Scope{}, %Elixir.SmeeView.Aspects.Scope{}]\n```","ref":"SmeeView.Scopes.html#view/3"},{"type":"function","title":"SmeeView.Scopes.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.Scope` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nScopes.view_one(entity)\n# => %Elixir.SmeeView.Aspects.Scope{}\n```","ref":"SmeeView.Scopes.html#view_one/3"},{"type":"module","title":"SmeeView.ServiceDescriptions","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.ServiceDescriptions.html"},{"type":"function","title":"SmeeView.ServiceDescriptions.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nServiceDescriptions.idp_filter(view)\n# => []\n```","ref":"SmeeView.ServiceDescriptions.html#idp_filter/1"},{"type":"function","title":"SmeeView.ServiceDescriptions.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.ServiceDescription` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nServiceDescriptions.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.ServiceDescription{}, %Elixir.SmeeView.Aspects.ServiceDescription{},]}\n```","ref":"SmeeView.ServiceDescriptions.html#prism/3"},{"type":"function","title":"SmeeView.ServiceDescriptions.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nServiceDescriptions.sp_filter(view)\n# => []\n```","ref":"SmeeView.ServiceDescriptions.html#sp_filter/1"},{"type":"function","title":"SmeeView.ServiceDescriptions.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.ServiceDescription` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nServiceDescriptions.view(entity)\n# => [%Elixir.SmeeView.Aspects.ServiceDescription{}, %Elixir.SmeeView.Aspects.ServiceDescription{}]\n```","ref":"SmeeView.ServiceDescriptions.html#view/3"},{"type":"function","title":"SmeeView.ServiceDescriptions.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.ServiceDescription` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nServiceDescriptions.view_one(entity)\n# => %Elixir.SmeeView.Aspects.ServiceDescription{}\n```","ref":"SmeeView.ServiceDescriptions.html#view_one/3"},{"type":"module","title":"SmeeView.ServiceNames","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.ServiceNames.html"},{"type":"function","title":"SmeeView.ServiceNames.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nServiceNames.idp_filter(view)\n# => []\n```","ref":"SmeeView.ServiceNames.html#idp_filter/1"},{"type":"function","title":"SmeeView.ServiceNames.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.ServiceName` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nServiceNames.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.ServiceName{}, %Elixir.SmeeView.Aspects.ServiceName{},]}\n```","ref":"SmeeView.ServiceNames.html#prism/3"},{"type":"function","title":"SmeeView.ServiceNames.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nServiceNames.sp_filter(view)\n# => []\n```","ref":"SmeeView.ServiceNames.html#sp_filter/1"},{"type":"function","title":"SmeeView.ServiceNames.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.ServiceName` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nServiceNames.view(entity)\n# => [%Elixir.SmeeView.Aspects.ServiceName{}, %Elixir.SmeeView.Aspects.ServiceName{}]\n```","ref":"SmeeView.ServiceNames.html#view/3"},{"type":"function","title":"SmeeView.ServiceNames.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.ServiceName` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nServiceNames.view_one(entity)\n# => %Elixir.SmeeView.Aspects.ServiceName{}\n```","ref":"SmeeView.ServiceNames.html#view_one/3"},{"type":"module","title":"SmeeView.SigningMethods","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.SigningMethods.html"},{"type":"function","title":"SmeeView.SigningMethods.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nSigningMethods.idp_filter(view)\n# => []\n```","ref":"SmeeView.SigningMethods.html#idp_filter/1"},{"type":"function","title":"SmeeView.SigningMethods.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.SigningMethod` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSigningMethods.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.SigningMethod{}, %Elixir.SmeeView.Aspects.SigningMethod{},]}\n```","ref":"SmeeView.SigningMethods.html#prism/3"},{"type":"function","title":"SmeeView.SigningMethods.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nSigningMethods.sp_filter(view)\n# => []\n```","ref":"SmeeView.SigningMethods.html#sp_filter/1"},{"type":"function","title":"SmeeView.SigningMethods.truncate/1","doc":"Shortens algorithms\n\nRemoves the URI namespacing prefix from algorithms, making them smaller, friendlier, and potentially conflicting.\n\n```\nSigningMethods.truncate(aspects)\n# => [\"ecdsa-sha1\"]\n```","ref":"SmeeView.SigningMethods.html#truncate/1"},{"type":"function","title":"SmeeView.SigningMethods.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.SigningMethod` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSigningMethods.view(entity)\n# => [%Elixir.SmeeView.Aspects.SigningMethod{}, %Elixir.SmeeView.Aspects.SigningMethod{}]\n```","ref":"SmeeView.SigningMethods.html#view/3"},{"type":"function","title":"SmeeView.SigningMethods.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.SigningMethod` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSigningMethods.view_one(entity)\n# => %Elixir.SmeeView.Aspects.SigningMethod{}\n```","ref":"SmeeView.SigningMethods.html#view_one/3"},{"type":"module","title":"SmeeView.SingleLogoutServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.SingleLogoutServices.html"},{"type":"function","title":"SmeeView.SingleLogoutServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nSingleLogoutServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.SingleLogoutServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.SingleLogoutServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nSingleLogoutServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.SingleLogoutServices.html#bindings/1"},{"type":"function","title":"SmeeView.SingleLogoutServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nSingleLogoutServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.SingleLogoutServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.SingleLogoutServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.SingleLogoutService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSingleLogoutServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.SingleLogoutService{}, %Elixir.SmeeView.Aspects.SingleLogoutService{},]}\n```","ref":"SmeeView.SingleLogoutServices.html#prism/3"},{"type":"function","title":"SmeeView.SingleLogoutServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nSingleLogoutServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.SingleLogoutServices.html#sort/1"},{"type":"function","title":"SmeeView.SingleLogoutServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nSingleLogoutServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.SingleLogoutServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.SingleLogoutServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.SingleLogoutService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSingleLogoutServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.SingleLogoutService{}, %Elixir.SmeeView.Aspects.SingleLogoutService{}]\n```","ref":"SmeeView.SingleLogoutServices.html#view/3"},{"type":"function","title":"SmeeView.SingleLogoutServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.SingleLogoutService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSingleLogoutServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.SingleLogoutService{}\n```","ref":"SmeeView.SingleLogoutServices.html#view_one/3"},{"type":"module","title":"SmeeView.SingleSignonServices","doc":"This module can extracts the ` ` elements in entity metadata as \"aspect\" structs, and then\nprocess and filter the results.\n\nAspects can be extracted with three functions:\n\n* Views, via `view/3` are lists of aspects\n* Prisms, via `prism/3` are maps of entity IDs to views\n* There is also `view_one/3` which returns the first aspect found\n\nAspects can be extracted from `Smee.Metadata` structs, `Smee.Entity` structs, or lists of aspects, Metadata and Entity\n  structs.\n\nThe other functions in this module are intended to be applied to collections of aspect structs - for working with\n  individual aspects, please look at the appropriate Aspect module.","ref":"SmeeView.SingleSignonServices.html"},{"type":"function","title":"SmeeView.SingleSignonServices.binding_filter/2","doc":"Returns all services matching the specified binding\n\n```\nSingleSignonServices.binding_filter(aspect)\n# => []\n```","ref":"SmeeView.SingleSignonServices.html#binding_filter/2"},{"type":"function","title":"SmeeView.SingleSignonServices.bindings/1","doc":"Returns all bindings present in the view\n\n```\nSingleSignonServices.bindings(aspects)\n# => []\n```","ref":"SmeeView.SingleSignonServices.html#bindings/1"},{"type":"function","title":"SmeeView.SingleSignonServices.idp_filter/1","doc":"Removes any non-IdP aspects from a list (view) or map (prism)\n\n```\nSingleSignonServices.idp_filter(view)\n# => []\n```","ref":"SmeeView.SingleSignonServices.html#idp_filter/1"},{"type":"function","title":"SmeeView.SingleSignonServices.prism/3","doc":"Returns a map of `Elixir.SmeeView.Aspects.SingleSignonService` aspect structs extracted from the input data, with entity IDs as keys.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity` and/or `Smee.Metadata` structs.\nOnly appropriate aspect records will be returned.\n\n`prism/3` is useful for extracting specific types of aspects from lists of entity records, or metadata. If you are\n  only interested in one aspect from a single `Smee.Entity` struct then you should probably use `view/3` instead.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSingleSignonServices.prism(entity)\n# => %{\"https://example.com/shibboleth\" =>  [%Elixir.SmeeView.Aspects.SingleSignonService{}, %Elixir.SmeeView.Aspects.SingleSignonService{},]}\n```","ref":"SmeeView.SingleSignonServices.html#prism/3"},{"type":"function","title":"SmeeView.SingleSignonServices.sort/1","doc":"Sorts the services - only really has an impact if services have an index value set\n\n```\nSingleSignonServices.sort(aspect)\n# => [...]\n```","ref":"SmeeView.SingleSignonServices.html#sort/1"},{"type":"function","title":"SmeeView.SingleSignonServices.sp_filter/1","doc":"Removes any non-SP aspects from a list (view) or map (prism)\n\n```\nSingleSignonServices.sp_filter(view)\n# => []\n```","ref":"SmeeView.SingleSignonServices.html#sp_filter/1"},{"type":"function","title":"SmeeView.SingleSignonServices.view/3","doc":"Returns a list of `Elixir.SmeeView.Aspects.SingleSignonService` aspect structs extracted from the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects. Only appropriate aspect records will be returned.\n\n`view/3` is useful for extracting specific types of aspects from one Entity, but because it has no entity ID information\n  it's often not the best choice for handling Metadata. When extracting information from entire metadata it's often\n  better to use `prism/3` which returns the same data in a map, associated with each entity's ID.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSingleSignonServices.view(entity)\n# => [%Elixir.SmeeView.Aspects.SingleSignonService{}, %Elixir.SmeeView.Aspects.SingleSignonService{}]\n```","ref":"SmeeView.SingleSignonServices.html#view/3"},{"type":"function","title":"SmeeView.SingleSignonServices.view_one/3","doc":"Returns a single `Elixir.SmeeView.Aspects.SingleSignonService` aspect struct extracted from one record in the input data.\n\nInput data can be a `Smee.Entity` or `Smee.Metadata` struct, or a list containing `Smee.Entity`, `Smee.Metadata` or\n  any aspects.\n\n**Only one entity will be processed** and then **only one aspect will be returned**. If you pass one Entity struct as the input, it will be that entity (obviously).\n  If you pass metadata structs or lists one entity will be chosen at random. The first suitable entity will be returned.\n\n`view_one/3` is *intended* for use with a single entity record and aspects like `SmeeView.Aspect.Entity`,\n`SmeeView.Aspect.SP' or `SmeeView.Aspect.Organization' but will work with any aspect.\n\n The optional role parameter will optimize the results to only search for either :idp or :sp aspects. The default is :all.\n\n```\nSingleSignonServices.view_one(entity)\n# => %Elixir.SmeeView.Aspects.SingleSignonService{}\n```","ref":"SmeeView.SingleSignonServices.html#view_one/3"},{"type":"module","title":"SmeeView.Aspects.ArtifactResolutionService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.ArtifactResolutionService.html"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nArtifactResolutionService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nArtifactResolutionService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nArtifactResolutionService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nArtifactResolutionService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nArtifactResolutionService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nArtifactResolutionService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.ArtifactResolutionService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nArtifactResolutionService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.ArtifactResolutionService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.ArtifactResolutionService.t/0","doc":"","ref":"SmeeView.Aspects.ArtifactResolutionService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.AssertionConsumerService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.AssertionConsumerService.html"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nAssertionConsumerService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nAssertionConsumerService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nAssertionConsumerService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nAssertionConsumerService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nAssertionConsumerService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nAssertionConsumerService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.AssertionConsumerService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nAssertionConsumerService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AssertionConsumerService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.AssertionConsumerService.t/0","doc":"","ref":"SmeeView.Aspects.AssertionConsumerService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.AssertionIDRequestService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.AssertionIDRequestService.html"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nAssertionIDRequestService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nAssertionIDRequestService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nAssertionIDRequestService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nAssertionIDRequestService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nAssertionIDRequestService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nAssertionIDRequestService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.AssertionIDRequestService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nAssertionIDRequestService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AssertionIDRequestService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.AssertionIDRequestService.t/0","doc":"","ref":"SmeeView.Aspects.AssertionIDRequestService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Attribute","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Attribute.html"},{"type":"function","title":"SmeeView.Aspects.Attribute.defined_values/1","doc":"Returns any predefined values for this attribute, or an empty list\n\n```\nSmeeView.Aspects.Attribute.defined_values(aspect)\n# => [\"member\", \"affiliate\", \"staff\", \"student\"]\n```","ref":"SmeeView.Aspects.Attribute.html#defined_values/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.defined_values?/1","doc":"Returns true if the attribute has predefined values\n\n```\nSmeeView.Aspects.Attribute.defined_values?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Attribute.html#defined_values?/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.friendly_name/1","doc":"Returns the human-readable name for this attribute\n\n```\nAttribute.friendly_name(aspect)\n# => \"eduPersonScopedAffiliation\"\n```","ref":"SmeeView.Aspects.Attribute.html#friendly_name/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nAttribute.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Attribute.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.name/1","doc":"Returns the technical name for this attribute\n\n```\nAttribute.name(aspect)\n# => \"urn:oid:1.3.6.1.4.1.5923.1.1.1.9\"\n```","ref":"SmeeView.Aspects.Attribute.html#name/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.name_format/1","doc":"Returns for technical name format for this attribute\n\n(It'll almost certainly be \"urn:oasis:names:tc:SAML:2.0:attrname-format:uri\")\n\n```\nAttribute.name_format(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:attrname-format:uri\"\n```","ref":"SmeeView.Aspects.Attribute.html#name_format/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nAttribute.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Attribute.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.saml1?/1","doc":"Is this a SAML1 attribute? Returns true if passed a SAML1 attribute.\n\n```\nAttribute.saml1?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Attribute.html#saml1?/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.saml2?/1","doc":"Is this a SAML2 attribute? Returns true if a passed SAML2 attribute\n\n```\nAttribute.saml2?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Attribute.html#saml2?/1"},{"type":"function","title":"SmeeView.Aspects.Attribute.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nAttribute.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Attribute.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.Attribute.t/0","doc":"","ref":"SmeeView.Aspects.Attribute.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.AttributeConsumingService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module. Other modules may be needed for aspects of a different type\n  contained inside this one.","ref":"SmeeView.Aspects.AttributeConsumingService.html"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nAttributeConsumingService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.index/1","doc":"Returns the index integer for this endpoint/service\n```\nAttributeConsumingService.index(service)\n# => 1\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.requested_attributes/1","doc":"Returns a list of requested attributes, if any are present.\n\n```\nAttributeConsumingService.requested_attributes(service)\n# => [%RequestedAttribute{...}, %RequestedAttribute{...}]\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#requested_attributes/1"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nAttributeConsumingService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.service_descriptions/1","doc":"Returns a list of service descriptions (one per language)\n\n```\nAttributeConsumingService.service_descriptions(service)\n# => [%ServiceDescription{lang: \"en\", ...}, %ServiceDescription{lang: \"cn\", ...}]\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#service_descriptions/1"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.service_names/1","doc":"Returns a list of service names (one per language)\n\n```\nAttributeConsumingService.service_names(aspect)\n# => [%ServiceName{lang: \"en\", ...}, %ServiceName{lang: \"cn\", ...}]\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#service_names/1"},{"type":"function","title":"SmeeView.Aspects.AttributeConsumingService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nAttributeConsumingService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.AttributeConsumingService.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.AttributeConsumingService.t/0","doc":"","ref":"SmeeView.Aspects.AttributeConsumingService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.AttributeService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.AttributeService.html"},{"type":"function","title":"SmeeView.Aspects.AttributeService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nAttributeService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.AttributeService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.AttributeService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nAttributeService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.AttributeService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.AttributeService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nAttributeService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AttributeService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.AttributeService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nAttributeService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.AttributeService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.AttributeService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nAttributeService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.AttributeService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.AttributeService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nAttributeService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.AttributeService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.AttributeService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nAttributeService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.AttributeService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.AttributeService.t/0","doc":"","ref":"SmeeView.Aspects.AttributeService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Contact","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Contact.html"},{"type":"function","title":"SmeeView.Aspects.Contact.company/1","doc":"Returns the company name, if present (it probably isn't!)\n\n```\nContact.company(aspect)\n# => \"Unseen University\"\n```","ref":"SmeeView.Aspects.Contact.html#company/1"},{"type":"function","title":"SmeeView.Aspects.Contact.displayname/1","doc":"Returns the suggested display name of a contact, derived from given name, surname and company.\n\n```\nContact.displayname(contact)\n# => \"Ponder Stibbons (Unseen University)\"\n```","ref":"SmeeView.Aspects.Contact.html#displayname/1"},{"type":"function","title":"SmeeView.Aspects.Contact.email/1","doc":"Returns the email address as a bare email address (without name, not a URL)\n\n```\nContact.email(contact)\n# => \"ponders@unseen.edu\"\n```","ref":"SmeeView.Aspects.Contact.html#email/1"},{"type":"function","title":"SmeeView.Aspects.Contact.email_url/1","doc":"Returns the contact's email address as a URL (as it's stored in the metadata, probably)\n\n```\nContact.email_url(contact)\n# => \"mailto:ponders@unseen.edu\"\n```","ref":"SmeeView.Aspects.Contact.html#email_url/1"},{"type":"function","title":"SmeeView.Aspects.Contact.givenname/1","doc":"Returns the contact's givenname, if present\n\n```\nContact.givenname(contact)\n# => \"Ponder\"\n```","ref":"SmeeView.Aspects.Contact.html#givenname/1"},{"type":"function","title":"SmeeView.Aspects.Contact.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nContact.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Contact.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Contact.name_addr/1","doc":"Returns the email address and name in RFC5322 name-addr format (name  )\n\n```\nContact.name_addr(contact)\n# => \"Ponder Stibbons  \"\n```","ref":"SmeeView.Aspects.Contact.html#name_addr/1"},{"type":"function","title":"SmeeView.Aspects.Contact.phone/1","doc":"Returns the phone number of the contact, if present.\n\n```\nContact.phone(contact)\n# => \"01632960808\"\n```","ref":"SmeeView.Aspects.Contact.html#phone/1"},{"type":"function","title":"SmeeView.Aspects.Contact.phone_url/1","doc":"Returns the phone number of the contact (or nil) as a URL, as it probably isn't stored in the metadata\n\n```\nContact.phone_url(contact)\n# => \"tel:01632960808\"\n```","ref":"SmeeView.Aspects.Contact.html#phone_url/1"},{"type":"function","title":"SmeeView.Aspects.Contact.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nContact.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Contact.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Contact.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nContact.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Contact.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Contact.surname/1","doc":"Returns the surname of the contact, if present.\n\n```\nContact.surname(contact)\n# => \"Stibbons\"\n```","ref":"SmeeView.Aspects.Contact.html#surname/1"},{"type":"function","title":"SmeeView.Aspects.Contact.type/1","doc":"Returns the contact type (technical, support, administrative, billing, or other)\n\n```\nContact.type(contact)\n# => \"administrative\"\n```","ref":"SmeeView.Aspects.Contact.html#type/1"},{"type":"type","title":"SmeeView.Aspects.Contact.t/0","doc":"","ref":"SmeeView.Aspects.Contact.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Description","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Description.html"},{"type":"function","title":"SmeeView.Aspects.Description.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDescription.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Description.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Description.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nDescription.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.Description.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.Description.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nDescription.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.Description.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.Description.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDescription.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Description.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Description.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDescription.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Description.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Description.text/1","doc":"Returns the text for the aspect.\n\nIf you are trying to show the text for a particular language then use a function from the matching View\n  instead, and provide a list of aspects for it to choose from.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nDescription.text(aspect)\n# => \"Example University IdP\"\n```","ref":"SmeeView.Aspects.Description.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Description.t/0","doc":"","ref":"SmeeView.Aspects.Description.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.DigestMethod","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.DigestMethod.html"},{"type":"function","title":"SmeeView.Aspects.DigestMethod.algorithm/1","doc":"Returns the name/text for this algorithm.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nDigestMethod.algorithm(aspect)\n# => \"http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1\"\n```","ref":"SmeeView.Aspects.DigestMethod.html#algorithm/1"},{"type":"function","title":"SmeeView.Aspects.DigestMethod.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDigestMethod.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.DigestMethod.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.DigestMethod.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDigestMethod.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.DigestMethod.html#role/1"},{"type":"function","title":"SmeeView.Aspects.DigestMethod.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDigestMethod.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.DigestMethod.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.DigestMethod.truncate/1","doc":"Removes the namespace for the algorithm, leaving a smaller, friendlier, potentially colliding name\n\n```\nDigestMethod.truncate(aspect)\n# => \"ecdsa-sha1\"\n```","ref":"SmeeView.Aspects.DigestMethod.html#truncate/1"},{"type":"type","title":"SmeeView.Aspects.DigestMethod.t/0","doc":"","ref":"SmeeView.Aspects.DigestMethod.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.DiscoHints","doc":"This aspect contains a bundle of related Discovery (\"Disco\") aspects from entity metadata.\n\nSince scopes, networks, gelocations, domains, keywords, etc are often used together this Aspect exists to make\ngathering them all a little simpler.\n\nYou can extract and process each of the different types of aspects using their own View modules:\n\n* `SmeeView.Scopes`\n* `SmeeView.Networks`\n* `SmeeView.Geolocations`\n* `SmeeView.Keywords`\n* `SmeeView.Domains`","ref":"SmeeView.Aspects.DiscoHints.html"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.domains/1","doc":"Return list of domain asspects (from   elements)\n\n```\nDiscoHints.domains(aspect)\n# => [%Domain{}, %Domain{}]\n```","ref":"SmeeView.Aspects.DiscoHints.html#domains/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.geolocations/1","doc":"Returns a list of geolocation aspects (from   elements)\n\n```\nDiscoHints.geolocations(aspect)\n# => [%Network{}. %Network{}]\n```","ref":"SmeeView.Aspects.DiscoHints.html#geolocations/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDiscoHints.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.DiscoHints.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.keywords/1","doc":"Returns list of keyword aspects (from   elements)\n\n```\nDiscoHints.keywords(aspect)\n# => [%Keywords{}]\n```","ref":"SmeeView.Aspects.DiscoHints.html#keywords/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.networks/1","doc":"Returns a list of network aspects (from   elements)\n\n```\nDiscoHints.networks(aspect)\n# => [%Network{}. %Network{}]\n```","ref":"SmeeView.Aspects.DiscoHints.html#networks/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDiscoHints.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.DiscoHints.html#role/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.scopes/1","doc":"Returns a list of scope aspects used by the entity\n\n```\nDiscoHints.scopes(aspect)\n# => [%Scope{regex: false, domain: \"unseen.edu\"}]\n```","ref":"SmeeView.Aspects.DiscoHints.html#scopes/1"},{"type":"function","title":"SmeeView.Aspects.DiscoHints.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDiscoHints.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.DiscoHints.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.DiscoHints.t/0","doc":"","ref":"SmeeView.Aspects.DiscoHints.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.DiscoUI","doc":"This aspect contains a bundle of related Metadata UI (\"mdui:\") aspects from entity metadata.\n\nSince displaynames, descriptions, URLs, etc are often used together this Aspect exists to make\ngathering them all a little simpler.\n\nYou can extract and process each of the different types of aspects using their own View modules:\n\n* `SmeeView.Displaynames`\n* `SmeeView.Descriptions`\n* `SmeeView.Logos`\n* `SmeeView.PrivacyURLs`\n* `SmeeView.InformationURLs`\n* `SmeeView.Keywords`\n* `SmeeView.Organization`","ref":"SmeeView.Aspects.DiscoUI.html"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.descriptions/1","doc":"Returns list of description aspects (from   elements)\n\n```\nDiscoUI.descriptions(aspect)\n# => [%Description{}, %Description{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#descriptions/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.displaynames/1","doc":"Returns list of displaynames aspects (from   elements)\n\n```\nDiscoUI.displaynames(aspect)\n# => [%Displayname{}, %Displayname{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#displaynames/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDiscoUI.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.DiscoUI.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.information_urls/1","doc":"Returns a list of Information URLs (from   elements)\n\n```\nDiscoUI.information_urls(aspect)\n# => [%InformationURL{}, %InformationURL{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#information_urls/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.keywords/1","doc":"Returns list of keyword aspects (from   elements)\n\n```\nDiscoUI.keywords(aspect)\n# => [%Keywords{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#keywords/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.logos/1","doc":"Returns list of logo aspects (from   elements)\n\n```\nDiscoUI.logos(aspect)\n# => [%Logo{}, %Logo{}, %Logo{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#logos/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.organization/1","doc":"Returns the first Organizations (there is probably just one) for use if MDUI information is missing\n\n\n```\nDiscoUI.organization(aspect)\n# => %Organization{}\n```","ref":"SmeeView.Aspects.DiscoUI.html#organization/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.organizations/1","doc":"Returns a list of Organizations (probably just one) for use if MDUI information is missing\n\n```\nDiscoUI.organizations(aspect)\n# => [%Organization{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#organizations/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.privacy_urls/1","doc":"Returns a list of Privacy URLs (from   elements)\n\n```\nDiscoUI.privacy_urls(aspect)\n# => [%PrivacyURL{}, %PrivacyURL{}]\n```","ref":"SmeeView.Aspects.DiscoUI.html#privacy_urls/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDiscoUI.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.DiscoUI.html#role/1"},{"type":"function","title":"SmeeView.Aspects.DiscoUI.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDiscoUI.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.DiscoUI.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.DiscoUI.t/0","doc":"","ref":"SmeeView.Aspects.DiscoUI.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.DiscoveryResponse","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.DiscoveryResponse.html"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nDiscoveryResponse.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nDiscoveryResponse.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDiscoveryResponse.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nDiscoveryResponse.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#index/1"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDiscoveryResponse.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#role/1"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDiscoveryResponse.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.DiscoveryResponse.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nDiscoveryResponse.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.DiscoveryResponse.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.DiscoveryResponse.t/0","doc":"","ref":"SmeeView.Aspects.DiscoveryResponse.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Displayname","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Displayname.html"},{"type":"function","title":"SmeeView.Aspects.Displayname.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDisplayname.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Displayname.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Displayname.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nDisplayname.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.Displayname.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.Displayname.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nDisplayname.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.Displayname.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.Displayname.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDisplayname.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Displayname.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Displayname.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDisplayname.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Displayname.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Displayname.text/1","doc":"Returns the text for the aspect.\n\nIf you are trying to show the text for a particular language then use a function from the matching View\n  instead, and provide a list of aspects for it to choose from.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nDisplayname.text(aspect)\n# => \"Example University IdP\"\n```","ref":"SmeeView.Aspects.Displayname.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Displayname.t/0","doc":"","ref":"SmeeView.Aspects.Displayname.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Domain","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Domain.html"},{"type":"function","title":"SmeeView.Aspects.Domain.domain/1","doc":"Returns the domain as a string\n\n```\nDomain.domain(aspect)\n# => \"unseen.edu\"\n```","ref":"SmeeView.Aspects.Domain.html#domain/1"},{"type":"function","title":"SmeeView.Aspects.Domain.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nDomain.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Domain.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Domain.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nDomain.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Domain.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Domain.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nDomain.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Domain.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Domain.text/1","doc":"Returns the domain as a string\n\n```\nDomain.text8(aspect)\n# => \"unseen.edu\"\n```","ref":"SmeeView.Aspects.Domain.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Domain.t/0","doc":"","ref":"SmeeView.Aspects.Domain.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.EncryptionMethod","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.EncryptionMethod.html"},{"type":"function","title":"SmeeView.Aspects.EncryptionMethod.algorithm/1","doc":"Returns the name/text for this algorithm.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nEncryptionMethod.algorithm(aspect)\n# => \"http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1\"\n```","ref":"SmeeView.Aspects.EncryptionMethod.html#algorithm/1"},{"type":"function","title":"SmeeView.Aspects.EncryptionMethod.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nEncryptionMethod.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.EncryptionMethod.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.EncryptionMethod.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nEncryptionMethod.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.EncryptionMethod.html#role/1"},{"type":"function","title":"SmeeView.Aspects.EncryptionMethod.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nEncryptionMethod.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.EncryptionMethod.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.EncryptionMethod.truncate/1","doc":"Removes the namespace for the algorithm, leaving a smaller, friendlier, potentially colliding name\n\n```\nEncryptionMethod.truncate(aspect)\n# => \"ecdsa-sha1\"\n```","ref":"SmeeView.Aspects.EncryptionMethod.html#truncate/1"},{"type":"type","title":"SmeeView.Aspects.EncryptionMethod.t/0","doc":"","ref":"SmeeView.Aspects.EncryptionMethod.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Entity","doc":"This aspect contains a bundle of related aspects from entity metadata. It is the top-level structure for SmeeView.\n\nThis is the most complicated *and slowest* Aspect structure in SmeeView, so unless you need everything within this\n  structure, you will probably be better off using other Views to extract only what you need directly.\n\nYou can extract and process each of the different types of aspects using their own View modules:","ref":"SmeeView.Aspects.Entity.html"},{"type":"function","title":"SmeeView.Aspects.Entity.cache_duration/1","doc":"Returns the cache duration value for the metadata, as a string\n\n```\nEntity.cache_duration(aspect)\n# => \"PT6H0M0.000S\"\n```","ref":"SmeeView.Aspects.Entity.html#cache_duration/1"},{"type":"function","title":"SmeeView.Aspects.Entity.contacts/1","doc":"Returns a list of all contact aspects in the entity\n\n```\nEntity.contacts(aspect)\n# => [%Contact{}, %Contact{}, %Contact{}]\n```","ref":"SmeeView.Aspects.Entity.html#contacts/1"},{"type":"function","title":"SmeeView.Aspects.Entity.entity_attributes/1","doc":"Returns a list of all Entity Attribute aspects for the entity\n\n```\nEntity.entity_attributes(aspect)\n# => [%EntityAttribute{}, %EntityAttribute{}, %EntityAttribute{}]\n```","ref":"SmeeView.Aspects.Entity.html#entity_attributes/1"},{"type":"function","title":"SmeeView.Aspects.Entity.entity_id/1","doc":"Returns the entity ID (URI) of the entity.\n\nThis is already available in the `Smee.Entity` record and the keys of prism data\n\n```\nEntity.entity_id(aspect)\n# => \"https://idp.example.com/shibboleth\"\n```","ref":"SmeeView.Aspects.Entity.html#entity_id/1"},{"type":"function","title":"SmeeView.Aspects.Entity.id/1","doc":"Returns the \"ID\" of the entity's metadata record *not the entity ID*.\n\nThis field will often be blank, and will differ for the same entity in different federations\n\nIt will often be \"_\" or nil\n```\nEntity.id(aspect)\n# => \"ex378486\"\n```","ref":"SmeeView.Aspects.Entity.html#id/1"},{"type":"function","title":"SmeeView.Aspects.Entity.idp/1","doc":"Returns the IdP role attribute for the entity, or nil\n\n```\nEntity.idp(aspect)\n# => %IdP{}\n```","ref":"SmeeView.Aspects.Entity.html#idp/1"},{"type":"function","title":"SmeeView.Aspects.Entity.idp?/1","doc":"Returns true if an IdP role is present\n\n```\nEntity.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Entity.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Entity.idps/1","doc":"Returns a list of all IdP role aspects (there will be zero or one IdPs in the list)\n\nSee `idp/1` too, which returns one or nil\n```\nEntity.idps(aspect)\n# => [%IdP{}]\n```","ref":"SmeeView.Aspects.Entity.html#idps/1"},{"type":"function","title":"SmeeView.Aspects.Entity.organization/1","doc":"Returns the top-level organization aspect for the entity, or nil\n\n```\nEntity.organization(aspect)\n# => %Organization{}\n```","ref":"SmeeView.Aspects.Entity.html#organization/1"},{"type":"function","title":"SmeeView.Aspects.Entity.organization?/1","doc":"Returns true if an Organization aspect is present\n\n```\nEntity.organization?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Entity.html#organization?/1"},{"type":"function","title":"SmeeView.Aspects.Entity.organizations/1","doc":"Returns a list of Organization aspects in the entity\n\n```\nEntity.organizations(aspect)\n# => [%Organization{}]\n```","ref":"SmeeView.Aspects.Entity.html#organizations/1"},{"type":"function","title":"SmeeView.Aspects.Entity.publications/1","doc":"PublicationPath - list of Publications for the entity\n\n```\nEntity.publications(aspect)\n# => [%Publication{}]\n```","ref":"SmeeView.Aspects.Entity.html#publications/1"},{"type":"function","title":"SmeeView.Aspects.Entity.registration/1","doc":"Registration aspect for the entity\n\n```\nEntity.registration(aspect)\n# => %Registration{}\n```","ref":"SmeeView.Aspects.Entity.html#registration/1"},{"type":"function","title":"SmeeView.Aspects.Entity.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nEntity.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Entity.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Entity.roles/1","doc":"Lists all roles for the Entity (IdPs, SPs, others)\n\n```\nEntity.roles(aspect)\n# => [%SP{}]\n```","ref":"SmeeView.Aspects.Entity.html#roles/1"},{"type":"function","title":"SmeeView.Aspects.Entity.sp/1","doc":"Returns the SP role attribute for the entity, or nil\n\n```\nEntity.sp(aspect)\n# => %SP{}\n```","ref":"SmeeView.Aspects.Entity.html#sp/1"},{"type":"function","title":"SmeeView.Aspects.Entity.sp?/1","doc":"Returns true if an SP role is present\n\n```\nEntity.sp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Entity.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Entity.sps/1","doc":"Returns a list of all SP role aspects (there will be zero or one SPs in the list)\n\nSee `sp/1` too, which returns one or nil\n```\nEntity.sps(aspect)\n# => [%SP{}]\n```","ref":"SmeeView.Aspects.Entity.html#sps/1"},{"type":"function","title":"SmeeView.Aspects.Entity.valid_until/1","doc":"Returns the valid until expiry date from the Entity.\n\nThis should already be available in the `Smee.Entity` record, but that may be derived from the default in the parent\nmetadata.\n\n```\nEntity.valid_until(aspect)\n# => \"2021-12-25T17:33:22.438Z\"\n```","ref":"SmeeView.Aspects.Entity.html#valid_until/1"},{"type":"type","title":"SmeeView.Aspects.Entity.t/0","doc":"","ref":"SmeeView.Aspects.Entity.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.EntityAttribute","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.EntityAttribute.html"},{"type":"function","title":"SmeeView.Aspects.EntityAttribute.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nEntityAttribute.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.EntityAttribute.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.EntityAttribute.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nEntityAttribute.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.EntityAttribute.html#role/1"},{"type":"function","title":"SmeeView.Aspects.EntityAttribute.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nEntityAttribute.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.EntityAttribute.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.EntityAttribute.t/0","doc":"","ref":"SmeeView.Aspects.EntityAttribute.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Geolocation","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Geolocation.html"},{"type":"function","title":"SmeeView.Aspects.Geolocation.geolocation/1","doc":"Returns the geolocation as a string\n\n```\nGeolocation.geolocation(aspect)\n# => \"geo:47.37328,8.531126\"\n```","ref":"SmeeView.Aspects.Geolocation.html#geolocation/1"},{"type":"function","title":"SmeeView.Aspects.Geolocation.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nGeolocation.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Geolocation.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Geolocation.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nGeolocation.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Geolocation.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Geolocation.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nGeolocation.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Geolocation.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Geolocation.text/1","doc":"Returns the geolocation as a string\n\n```\nGeolocation.text(aspect)\n# => \"geo:47.37328,8.531126\"\n```","ref":"SmeeView.Aspects.Geolocation.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Geolocation.t/0","doc":"","ref":"SmeeView.Aspects.Geolocation.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.IdP","doc":"This aspect contains a bundle of related aspects for the IdP role of an entity.\n\nSince displaynames, descriptions, URLs, etc are often used together this Aspect exists to make\ngathering them all a little simpler.\n\nYou can extract and process each of the different types of aspects using their own View modules:\n\n* `SmeeView.Displaynames`\n* `SmeeView.Names`\n* `SmeeView.Logos`\n* `SmeeView.PrivacyURLs`\n* `SmeeView.InformationURLs`\n* `SmeeView.Keywords`\n* `SmeeView.Organization`","ref":"SmeeView.Aspects.IdP.html"},{"type":"function","title":"SmeeView.Aspects.IdP.attributes/1","doc":"Lists of attributes associated with this role\n\n```\nIdP.attributes(aspect)\n# => [%Attribute{}, %Attribute{}]\n```","ref":"SmeeView.Aspects.IdP.html#attributes/1"},{"type":"function","title":"SmeeView.Aspects.IdP.displaynames/1","doc":"Lists MDUI displaynames used by this role\n\n```\nIdP.displaynames(aspect)\n# => [%Displayname{}, %Displayname{}, %Displayname{}]\n```","ref":"SmeeView.Aspects.IdP.html#displaynames/1"},{"type":"function","title":"SmeeView.Aspects.IdP.domains/1","doc":"Lists MD Disco domain hints as domain aspects\n\n```\nIdP.domains(aspect)\n# => [%Domain{}]\n```","ref":"SmeeView.Aspects.IdP.html#domains/1"},{"type":"function","title":"SmeeView.Aspects.IdP.geolocations/1","doc":"List MD Disco geolocation hints as geolocation aspects\n\n```\nIdP.geolocations(aspect)\n# => [Geolocation{},Geolocation{}]\n```","ref":"SmeeView.Aspects.IdP.html#geolocations/1"},{"type":"function","title":"SmeeView.Aspects.IdP.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nIdP.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.IdP.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.IdP.keys/1","doc":"Lists public keys for this role\n\n```\nIdP.keys(aspect)\n# => [%Key{}, %Key{}]\n```","ref":"SmeeView.Aspects.IdP.html#keys/1"},{"type":"function","title":"SmeeView.Aspects.IdP.keywords/1","doc":"Lists MD Disco keyword sets as Keywords aspects\n\n```\nIdP.keywords(aspect)\n# => [Keywords{}]\n```","ref":"SmeeView.Aspects.IdP.html#keywords/1"},{"type":"function","title":"SmeeView.Aspects.IdP.logos/1","doc":"Lists MDUI logos used by this role\n\n```\nIdP.logos(aspect)\n# => [Logo{}, Logo{}, Logo{}]\n```","ref":"SmeeView.Aspects.IdP.html#logos/1"},{"type":"function","title":"SmeeView.Aspects.IdP.nameid_formats/1","doc":"List NameID format URIs as aspects\n\n```\nIdP.nameid_formats(aspect)\n# => [%NameID{}]\n```","ref":"SmeeView.Aspects.IdP.html#nameid_formats/1"},{"type":"function","title":"SmeeView.Aspects.IdP.networks/1","doc":"Lists MDDisco IPHints as Network aspects\n\n```\nIdP.networks(aspect)\n# => [%Network{}, %Network{}]\n```","ref":"SmeeView.Aspects.IdP.html#networks/1"},{"type":"function","title":"SmeeView.Aspects.IdP.protocols/1","doc":"Returns a list of protocol aspects for this role\n\n```\nIdP.protocols(aspect)\n# => [%Protocol{}, %Protocol{}]\n```","ref":"SmeeView.Aspects.IdP.html#protocols/1"},{"type":"function","title":"SmeeView.Aspects.IdP.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nIdP.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.IdP.html#role/1"},{"type":"function","title":"SmeeView.Aspects.IdP.scopes/1","doc":"Lists Shibboleth domain scopes used by the IdP (*not* oauth/OIDC scopes)\n\n```\nIdP.scopes(aspect)\n# => [%Scope{regex: false, domain: \"unseen.edu\"}]\n```","ref":"SmeeView.Aspects.IdP.html#scopes/1"},{"type":"function","title":"SmeeView.Aspects.IdP.services/1","doc":"Lists all types of services for this role\n\n```\nIdP.services(aspect)\n# => [%SingleSignOnService{}, %SingleLogoutService{}]\n```","ref":"SmeeView.Aspects.IdP.html#services/1"},{"type":"function","title":"SmeeView.Aspects.IdP.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nIdP.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.IdP.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.IdP.want_authn_requests_signed?/1","doc":"Returns true if the IdP demands Authn requests to be signed\n\n```\nIdP.want_authn_requests_signed?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.IdP.html#want_authn_requests_signed?/1"},{"type":"type","title":"SmeeView.Aspects.IdP.t/0","doc":"","ref":"SmeeView.Aspects.IdP.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.InformationURL","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.InformationURL.html"},{"type":"function","title":"SmeeView.Aspects.InformationURL.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nInformationURL.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.InformationURL.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.InformationURL.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nInformationURL.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.InformationURL.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.InformationURL.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nInformationURL.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.InformationURL.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.InformationURL.parsed!/1","doc":"Returns the URL for this aspect as a parsed URI struct.\n\nIf the URI cannot be parsed then an exception will be raised. If you need more control you should either\n  use `valid?/1` first, or just use `URI.parse/1` yourself.\n\n```\nInformationURL.parsed!(aspect)\n# => %URI{...}\n```","ref":"SmeeView.Aspects.InformationURL.html#parsed!/1"},{"type":"function","title":"SmeeView.Aspects.InformationURL.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nInformationURL.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.InformationURL.html#role/1"},{"type":"function","title":"SmeeView.Aspects.InformationURL.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nInformationURL.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.InformationURL.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.InformationURL.url/1","doc":"Returns the URL for this aspect, as a text binary\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nInformationURL.url(aspect)\n# => \"https://idp.example.com/information\"\n```","ref":"SmeeView.Aspects.InformationURL.html#url/1"},{"type":"function","title":"SmeeView.Aspects.InformationURL.valid?/1","doc":"Is this a valid URL? Returns true if the URL can be parsed.\n\n```\nInformationURL.valid?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.InformationURL.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.InformationURL.t/0","doc":"","ref":"SmeeView.Aspects.InformationURL.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Key","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThis is information about the keys used by an IdP or SP for signing and encryption and contains the *public key*\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Key.html"},{"type":"function","title":"SmeeView.Aspects.Key.data/1","doc":"Returns the raw BASE64 string data of the key, without PEM headers, as stored in the metadata\n\n```\nKey.data(aspect)\n# => \"MIICMzCCAZygAwIBAgIJALiPnVsvq...\"\n```","ref":"SmeeView.Aspects.Key.html#data/1"},{"type":"function","title":"SmeeView.Aspects.Key.encryption?/1","doc":"Is the key suitable for encryption use?\n\nNot that this is *used for*, not specifically for - a type of nil indicates both signing and encryption use.\n\n```\nKey.encryption?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Key.html#encryption?/1"},{"type":"function","title":"SmeeView.Aspects.Key.expires_at/1","doc":"Returns the expiry date (Not After) for the certificate\n\n```\nKey.expires_at(aspect)\n# => ~U[2023-05-21 16:12:05.481701Z]\n```","ref":"SmeeView.Aspects.Key.html#expires_at/1"},{"type":"function","title":"SmeeView.Aspects.Key.fingerprint/1","doc":"Returns the SHA1 fingerprint of the certificate\n\n```\nKey.fingerprint(aspect)\n# => \"A5:9C:E0:47:C1:34:88:9F:16:0B:15:0C:9E:A1:B9:05:6D:8C:37:FE\"\n```","ref":"SmeeView.Aspects.Key.html#fingerprint/1"},{"type":"function","title":"SmeeView.Aspects.Key.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nKey.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Key.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Key.issuer/1","doc":"Returns the issuer CN of the certificate\n\n```\nKey.issuer(aspect)\n# => \"CN=Ankh Morpork Post Office\"\n```","ref":"SmeeView.Aspects.Key.html#issuer/1"},{"type":"function","title":"SmeeView.Aspects.Key.pem/1","doc":"Returns the public key as a PEM string (a BASE64-encoded DER certificate).\n\n```\nKey.pem(aspect)\n# => \"-----BEGIN CERTIFICATE-----\n#MIICMzCCAZygAwIBAgIJALiPnVsvq...\"\n```","ref":"SmeeView.Aspects.Key.html#pem/1"},{"type":"function","title":"SmeeView.Aspects.Key.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nKey.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Key.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Key.serial_number/1","doc":"Returns the serial number for the certificate\n\n```\nKey.serial_number(aspect)\n# => \"27ACAE30B9F323\"\n```","ref":"SmeeView.Aspects.Key.html#serial_number/1"},{"type":"function","title":"SmeeView.Aspects.Key.signature_algorithm/1","doc":"Return the signature algorithm as a string (not a list!)\n\n```\nKey.signature_algorithm(aspect)\n# => \"sha, rsa\"\n```","ref":"SmeeView.Aspects.Key.html#signature_algorithm/1"},{"type":"function","title":"SmeeView.Aspects.Key.signing?/1","doc":"Is the key suitable for signing use?\n\nNot that this is *used for*, not specifically for - a type of nil indicates both signing and encryption use.\n\n```\nKey.signing?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Key.html#signing?/1"},{"type":"function","title":"SmeeView.Aspects.Key.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nKey.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Key.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Key.subject/1","doc":"Returns the subject CN of the key/certificate\n\n```\nKey.subject(aspect)\n# => \"/CN=hex.unseen.edu/OU=Domain Control Validated\"\n```","ref":"SmeeView.Aspects.Key.html#subject/1"},{"type":"function","title":"SmeeView.Aspects.Key.type/1","doc":"Return the key type: signing, encryption or nil. Nil indicates that the key is general-purpose.\n\n```\nKey.type(aspect)\n# => \"signing\"\n```","ref":"SmeeView.Aspects.Key.html#type/1"},{"type":"type","title":"SmeeView.Aspects.Key.t/0","doc":"","ref":"SmeeView.Aspects.Key.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Keywords","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Keywords.html"},{"type":"function","title":"SmeeView.Aspects.Keywords.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nKeywords.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Keywords.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Keywords.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nKeywords.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.Keywords.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.Keywords.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nKeywords.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.Keywords.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.Keywords.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nKeywords.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Keywords.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Keywords.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nKeywords.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Keywords.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Keywords.text/1","doc":"Lists all keywords in this set as a single binary string\n\n```\nKeywords.text(aspect)\n# => \"GÉANT geant Terena Dante\"\n```","ref":"SmeeView.Aspects.Keywords.html#text/1"},{"type":"function","title":"SmeeView.Aspects.Keywords.words/1","doc":"Returns the keywords in one keyword set as a list of strings\n\n```\nKeywords.words(aspect)\n# => [\"GÉANT\", \"geant\", \"Terena\" \"Dante\"]\n```","ref":"SmeeView.Aspects.Keywords.html#words/1"},{"type":"type","title":"SmeeView.Aspects.Keywords.t/0","doc":"","ref":"SmeeView.Aspects.Keywords.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Logo","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Logo.html"},{"type":"function","title":"SmeeView.Aspects.Logo.data?/1","doc":"Is the URL a `data:` URL containing the actual logo, rather than a normal HTTP address?\n\n```\nLogo.data?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Logo.html#data?/1"},{"type":"function","title":"SmeeView.Aspects.Logo.format/1","doc":"Returns the file format of the image, if known, based on the URL\n\n```\nLogo.format(aspect)\n# => :png\n```","ref":"SmeeView.Aspects.Logo.html#format/1"},{"type":"function","title":"SmeeView.Aspects.Logo.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nLogo.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Logo.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Logo.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nLogo.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.Logo.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.Logo.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nLogo.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.Logo.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.Logo.parsed!/1","doc":"Returns the URL for this aspect as a parsed URI struct.\n\nIf the URI cannot be parsed then an exception will be raised. If you need more control you should either\n  use `valid?/1` first, or just use `URI.parse/1` yourself.\n\n```\nLogo.parsed!(aspect)\n# => %URI{...}\n```","ref":"SmeeView.Aspects.Logo.html#parsed!/1"},{"type":"function","title":"SmeeView.Aspects.Logo.pixels/1","doc":"Returns the total number of pixels (X x Y)\n\n```\nLogo.pixels(aspect)\n# => 4096\n```","ref":"SmeeView.Aspects.Logo.html#pixels/1"},{"type":"function","title":"SmeeView.Aspects.Logo.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nLogo.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Logo.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Logo.shape/1","doc":"Returns the shape of the logo (:square, :portrait or :landscape)\n\nIt's currently rather crude - only *exact* squares will return `:square`\n\n```\nLogo.shape(aspect)\n# => :landscape\n```","ref":"SmeeView.Aspects.Logo.html#shape/1"},{"type":"function","title":"SmeeView.Aspects.Logo.size/1","doc":"Returns the size of the logo as a word. These words are currently arbitrary, from an old application\n\nSizes are: :tiny, :small, :icon, :default, :medium, :large, :huge and :silly\n\n```\nLogo.size(aspect)\n# => :large\n```","ref":"SmeeView.Aspects.Logo.html#size/1"},{"type":"function","title":"SmeeView.Aspects.Logo.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nLogo.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Logo.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Logo.tls?/1","doc":"Does the logo use a HTTPS URL?\n\n```\nLogo.tls?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Logo.html#tls?/1"},{"type":"function","title":"SmeeView.Aspects.Logo.url/1","doc":"Returns the URL for this aspect, as a text binary\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nLogo.url(aspect)\n# => \"https://idp.example.com/information\"\n```","ref":"SmeeView.Aspects.Logo.html#url/1"},{"type":"function","title":"SmeeView.Aspects.Logo.valid?/1","doc":"Is this a valid URL? Returns true if the URL can be parsed.\n\n```\nLogo.valid?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Logo.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.Logo.t/0","doc":"","ref":"SmeeView.Aspects.Logo.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.ManageNameidService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.ManageNameidService.html"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nManageNameidService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.ManageNameidService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nManageNameidService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.ManageNameidService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nManageNameidService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.ManageNameidService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nManageNameidService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.ManageNameidService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nManageNameidService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.ManageNameidService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nManageNameidService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.ManageNameidService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.ManageNameidService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nManageNameidService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.ManageNameidService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.ManageNameidService.t/0","doc":"","ref":"SmeeView.Aspects.ManageNameidService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.NameIDFormat","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.NameIDFormat.html"},{"type":"function","title":"SmeeView.Aspects.NameIDFormat.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nNameIDFormat.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.NameIDFormat.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.NameIDFormat.nameid/1","doc":"Returns the value of the nameid as a string\n\n```\nNameIDFormat.nameid(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:nameid-format:persistent\"\n```","ref":"SmeeView.Aspects.NameIDFormat.html#nameid/1"},{"type":"function","title":"SmeeView.Aspects.NameIDFormat.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nNameIDFormat.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.NameIDFormat.html#role/1"},{"type":"function","title":"SmeeView.Aspects.NameIDFormat.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nNameIDFormat.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.NameIDFormat.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.NameIDFormat.text/1","doc":"Returns the value of the nameid as a string\n\n```\nNameIDFormat.text(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:nameid-format:persistent\"\n```","ref":"SmeeView.Aspects.NameIDFormat.html#text/1"},{"type":"type","title":"SmeeView.Aspects.NameIDFormat.t/0","doc":"","ref":"SmeeView.Aspects.NameIDFormat.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.NameidMappingService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.NameidMappingService.html"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nNameidMappingService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.NameidMappingService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nNameidMappingService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.NameidMappingService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nNameidMappingService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.NameidMappingService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nNameidMappingService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.NameidMappingService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nNameidMappingService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.NameidMappingService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nNameidMappingService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.NameidMappingService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.NameidMappingService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nNameidMappingService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.NameidMappingService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.NameidMappingService.t/0","doc":"","ref":"SmeeView.Aspects.NameidMappingService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Network","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Network.html"},{"type":"function","title":"SmeeView.Aspects.Network.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nNetwork.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Network.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Network.network/1","doc":"Returns the value of the network/IPHint as a string\n\n```\nNetwork.network(aspect)\n# => \"130.88.0.0/16\"\n```","ref":"SmeeView.Aspects.Network.html#network/1"},{"type":"function","title":"SmeeView.Aspects.Network.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nNetwork.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Network.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Network.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nNetwork.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Network.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Network.text/1","doc":"Returns the value of the network/IPHint as a string\n\n```\nNetwork.text(aspect)\n# => \"130.88.0.0/16\"\n```","ref":"SmeeView.Aspects.Network.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Network.t/0","doc":"","ref":"SmeeView.Aspects.Network.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Organization","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Organization.html"},{"type":"function","title":"SmeeView.Aspects.Organization.displaynames/1","doc":"Lists all displaynames for this organization (one for each language)\n\n```\nOrganization.displaynames(aspect)\n# => [OrganizationDisplayname{}, OrganizationDisplayname{}, OrganizationDisplayname{}]\n```","ref":"SmeeView.Aspects.Organization.html#displaynames/1"},{"type":"function","title":"SmeeView.Aspects.Organization.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nOrganization.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Organization.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Organization.names/1","doc":"Lists all names for this organization (one for each language)\n\n```\nOrganization.names(aspect)\n# => [OrganizationName{}, OrganizationName{}, OrganizationName{}]\n```","ref":"SmeeView.Aspects.Organization.html#names/1"},{"type":"function","title":"SmeeView.Aspects.Organization.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nOrganization.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Organization.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Organization.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nOrganization.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Organization.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Organization.urls/1","doc":"Lists all URLs for this organization (one for each language)\n\n```\nOrganization.urls(aspect)\n# => [OrganizationURL{}, OrganizationURL{}, OrganizationURL{}]\n```","ref":"SmeeView.Aspects.Organization.html#urls/1"},{"type":"type","title":"SmeeView.Aspects.Organization.t/0","doc":"","ref":"SmeeView.Aspects.Organization.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.OrganizationDisplayname","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.OrganizationDisplayname.html"},{"type":"function","title":"SmeeView.Aspects.OrganizationDisplayname.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nOrganizationDisplayname.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.OrganizationDisplayname.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationDisplayname.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nOrganizationDisplayname.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.OrganizationDisplayname.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationDisplayname.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nOrganizationDisplayname.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.OrganizationDisplayname.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.OrganizationDisplayname.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nOrganizationDisplayname.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.OrganizationDisplayname.html#role/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationDisplayname.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nOrganizationDisplayname.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.OrganizationDisplayname.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationDisplayname.text/1","doc":"Returns the text for the aspect.\n\nIf you are trying to show the text for a particular language then use a function from the matching View\n  instead, and provide a list of aspects for it to choose from.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nOrganizationDisplayname.text(aspect)\n# => \"Example University IdP\"\n```","ref":"SmeeView.Aspects.OrganizationDisplayname.html#text/1"},{"type":"type","title":"SmeeView.Aspects.OrganizationDisplayname.t/0","doc":"","ref":"SmeeView.Aspects.OrganizationDisplayname.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.OrganizationName","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.OrganizationName.html"},{"type":"function","title":"SmeeView.Aspects.OrganizationName.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nOrganizationName.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.OrganizationName.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationName.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nOrganizationName.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.OrganizationName.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationName.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nOrganizationName.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.OrganizationName.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.OrganizationName.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nOrganizationName.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.OrganizationName.html#role/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationName.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nOrganizationName.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.OrganizationName.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationName.text/1","doc":"Returns the text for the aspect.\n\nIf you are trying to show the text for a particular language then use a function from the matching View\n  instead, and provide a list of aspects for it to choose from.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nOrganizationName.text(aspect)\n# => \"Example University IdP\"\n```","ref":"SmeeView.Aspects.OrganizationName.html#text/1"},{"type":"type","title":"SmeeView.Aspects.OrganizationName.t/0","doc":"","ref":"SmeeView.Aspects.OrganizationName.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.OrganizationURL","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.OrganizationURL.html"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nOrganizationURL.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.OrganizationURL.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nOrganizationURL.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.OrganizationURL.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nOrganizationURL.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.OrganizationURL.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.parsed!/1","doc":"Returns the URL for this aspect as a parsed URI struct.\n\nIf the URI cannot be parsed then an exception will be raised. If you need more control you should either\n  use `valid?/1` first, or just use `URI.parse/1` yourself.\n\n```\nOrganizationURL.parsed!(aspect)\n# => %URI{...}\n```","ref":"SmeeView.Aspects.OrganizationURL.html#parsed!/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nOrganizationURL.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.OrganizationURL.html#role/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nOrganizationURL.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.OrganizationURL.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.url/1","doc":"Returns the URL for this aspect, as a text binary\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nOrganizationURL.url(aspect)\n# => \"https://idp.example.com/information\"\n```","ref":"SmeeView.Aspects.OrganizationURL.html#url/1"},{"type":"function","title":"SmeeView.Aspects.OrganizationURL.valid?/1","doc":"Is this a valid URL? Returns true if the URL can be parsed.\n\n```\nOrganizationURL.valid?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.OrganizationURL.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.OrganizationURL.t/0","doc":"","ref":"SmeeView.Aspects.OrganizationURL.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.PrivacyURL","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.PrivacyURL.html"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nPrivacyURL.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.PrivacyURL.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nPrivacyURL.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.PrivacyURL.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nPrivacyURL.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.PrivacyURL.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.parsed!/1","doc":"Returns the URL for this aspect as a parsed URI struct.\n\nIf the URI cannot be parsed then an exception will be raised. If you need more control you should either\n  use `valid?/1` first, or just use `URI.parse/1` yourself.\n\n```\nPrivacyURL.parsed!(aspect)\n# => %URI{...}\n```","ref":"SmeeView.Aspects.PrivacyURL.html#parsed!/1"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nPrivacyURL.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.PrivacyURL.html#role/1"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nPrivacyURL.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.PrivacyURL.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.url/1","doc":"Returns the URL for this aspect, as a text binary\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nPrivacyURL.url(aspect)\n# => \"https://idp.example.com/information\"\n```","ref":"SmeeView.Aspects.PrivacyURL.html#url/1"},{"type":"function","title":"SmeeView.Aspects.PrivacyURL.valid?/1","doc":"Is this a valid URL? Returns true if the URL can be parsed.\n\n```\nPrivacyURL.valid?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.PrivacyURL.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.PrivacyURL.t/0","doc":"","ref":"SmeeView.Aspects.PrivacyURL.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Protocol","doc":"Represents and processes `protocolSupportEnumeration` XML attributes in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Protocol.html"},{"type":"function","title":"SmeeView.Aspects.Protocol.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nProtocol.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Protocol.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Protocol.protocol/1","doc":"Returns the protocol URI as a string binary.\n\n```\nProtocol.protocol(aspect)\n# => \"\"urn:oasis:names:tc:SAML:2.0:protocol\"\n```","ref":"SmeeView.Aspects.Protocol.html#protocol/1"},{"type":"function","title":"SmeeView.Aspects.Protocol.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nProtocol.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Protocol.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Protocol.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nProtocol.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Protocol.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Protocol.text/1","doc":"Returns the protocol URI as a string binary.\n\n```\nProtocol.text(aspect)\n# => \"\"urn:oasis:names:tc:SAML:2.0:protocol\"\n```","ref":"SmeeView.Aspects.Protocol.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Protocol.t/0","doc":"","ref":"SmeeView.Aspects.Protocol.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Publication","doc":"Represents and processes    elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Publication.html"},{"type":"function","title":"SmeeView.Aspects.Publication.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nPublication.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Publication.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Publication.publication_id/1","doc":"Returns the publication ID as a binary string.\n\n```\nPublication.publication_id(aspect)\n# => \"k3klsoi\"\n```","ref":"SmeeView.Aspects.Publication.html#publication_id/1"},{"type":"function","title":"SmeeView.Aspects.Publication.publisher/1","doc":"Returns the URI ID of the publisher as a binary string.\n\n```\nPublication.publisher(aspect)\n# => \"urn:mace:switch.ch:SWITCHaai\"\n```","ref":"SmeeView.Aspects.Publication.html#publisher/1"},{"type":"function","title":"SmeeView.Aspects.Publication.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nPublication.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Publication.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Publication.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nPublication.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Publication.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.Publication.t/0","doc":"","ref":"SmeeView.Aspects.Publication.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Registration","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Registration.html"},{"type":"function","title":"SmeeView.Aspects.Registration.authority/1","doc":"Returns the ID URI of the registrar/registration authority\n\n```\nRegistration.authority(aspect)\n# => \"http://ukfederation.org.uk\"\n```","ref":"SmeeView.Aspects.Registration.html#authority/1"},{"type":"function","title":"SmeeView.Aspects.Registration.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nRegistration.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Registration.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Registration.instant/1","doc":"xx\n\n```\nRegistration.instant(aspect)\n# => \"2014-11-07T16:35:40Z\"\n```","ref":"SmeeView.Aspects.Registration.html#instant/1"},{"type":"function","title":"SmeeView.Aspects.Registration.policies/1","doc":"Returns a list of any registration policies\n\n```\nRegistration.policies(aspect)\n# => [%RegistrationPolicy{lang=\"en\"}, %RegistrationPolicy{lang=\"sco\"}]\n```","ref":"SmeeView.Aspects.Registration.html#policies/1"},{"type":"function","title":"SmeeView.Aspects.Registration.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nRegistration.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Registration.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Registration.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nRegistration.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Registration.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.Registration.t/0","doc":"","ref":"SmeeView.Aspects.Registration.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.RegistrationPolicy","doc":"Represents and processes ` ` elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.RegistrationPolicy.html"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nRegistrationPolicy.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nRegistrationPolicy.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nRegistrationPolicy.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.parsed!/1","doc":"Returns the URL for this aspect as a parsed URI struct.\n\nIf the URI cannot be parsed then an exception will be raised. If you need more control you should either\n  use `valid?/1` first, or just use `URI.parse/1` yourself.\n\n```\nRegistrationPolicy.parsed!(aspect)\n# => %URI{...}\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#parsed!/1"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nRegistrationPolicy.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#role/1"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nRegistrationPolicy.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.url/1","doc":"Returns the URL for this aspect, as a text binary\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nRegistrationPolicy.url(aspect)\n# => \"https://idp.example.com/information\"\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#url/1"},{"type":"function","title":"SmeeView.Aspects.RegistrationPolicy.valid?/1","doc":"Is this a valid URL? Returns true if the URL can be parsed.\n\n```\nRegistrationPolicy.valid?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.RegistrationPolicy.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.RegistrationPolicy.t/0","doc":"","ref":"SmeeView.Aspects.RegistrationPolicy.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.RequestInitiator","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.RequestInitiator.html"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nRequestInitiator.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.RequestInitiator.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nRequestInitiator.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.RequestInitiator.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nRequestInitiator.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.RequestInitiator.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nRequestInitiator.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.RequestInitiator.html#index/1"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nRequestInitiator.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.RequestInitiator.html#role/1"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nRequestInitiator.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.RequestInitiator.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.RequestInitiator.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nRequestInitiator.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.RequestInitiator.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.RequestInitiator.t/0","doc":"","ref":"SmeeView.Aspects.RequestInitiator.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.RequestedAttribute","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.RequestedAttribute.html"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.friendly_name/1","doc":"Returns the human-readable name for this attribute\n\n```\nRequestedAttribute.friendly_name(aspect)\n# => \"eduPersonScopedAffiliation\"\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#friendly_name/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nRequestedAttribute.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.name/1","doc":"Returns the technical name for this attribute\n\n```\nRequestedAttribute.name(aspect)\n# => \"urn:oid:1.3.6.1.4.1.5923.1.1.1.9\"\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#name/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.name_format/1","doc":"Returns for technical name format for this attribute\n\n(It'll almost certainly be \"urn:oasis:names:tc:SAML:2.0:attrname-format:uri\")\n\n```\nRequestedAttribute.name_format(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:attrname-format:uri\"\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#name_format/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.optional?/1","doc":"Returns true if the attribute is optional\n\n```\nSmeeView.Aspects.RequestedAttribute.optional?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#optional?/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.required?/1","doc":"Returns true if the attribute is required\n\n```\nSmeeView.Aspects.RequestedAttribute.required?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#required?/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nRequestedAttribute.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#role/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.saml1?/1","doc":"Is this a SAML1 attribute? Returns true if passed a SAML1 attribute.\n\n```\nRequestedAttribute.saml1?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#saml1?/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.saml2?/1","doc":"Is this a SAML2 attribute? Returns true if a passed SAML2 attribute\n\n```\nRequestedAttribute.saml2?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#saml2?/1"},{"type":"function","title":"SmeeView.Aspects.RequestedAttribute.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nRequestedAttribute.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.RequestedAttribute.html#sp?/1"},{"type":"type","title":"SmeeView.Aspects.RequestedAttribute.t/0","doc":"","ref":"SmeeView.Aspects.RequestedAttribute.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.SP","doc":"This aspect contains a bundle of related aspects for the SP role of an entity.\n\nSince displaynames, descriptions, URLs, etc are often used together this Aspect exists to make\ngathering them all a little simpler.\n\nYou can extract and process each of the different types of aspects using their own View modules:\n\n* `SmeeView.Displaynames`\n* `SmeeView.Names`\n* `SmeeView.Logos`\n* `SmeeView.PrivacyURLs`\n* `SmeeView.InformationURLs`\n* `SmeeView.Keywords`\n* `SmeeView.Organization`","ref":"SmeeView.Aspects.SP.html"},{"type":"function","title":"SmeeView.Aspects.SP.authn_requests_signed?/1","doc":"Returns true if the signs authn requests is set\n\n```\nSP.authn_requests_signed?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.SP.html#authn_requests_signed?/1"},{"type":"function","title":"SmeeView.Aspects.SP.displaynames/1","doc":"Lists MDUI displaynames used by this role\n\n```\nSP.displaynames(aspect)\n# => [%Displayname{}, %Displayname{}, %Displayname{}]\n```","ref":"SmeeView.Aspects.SP.html#displaynames/1"},{"type":"function","title":"SmeeView.Aspects.SP.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nSP.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.SP.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.SP.keys/1","doc":"Lists public keys for this role\n\n```\nSP.keys(aspect)\n# => [%Key{}, %Key{}]\n```","ref":"SmeeView.Aspects.SP.html#keys/1"},{"type":"function","title":"SmeeView.Aspects.SP.keywords/1","doc":"Lists MD Disco keyword sets as Keywords aspects\n\n```\nSP.keywords(aspect)\n# => [Keywords{}]\n```","ref":"SmeeView.Aspects.SP.html#keywords/1"},{"type":"function","title":"SmeeView.Aspects.SP.logos/1","doc":"Lists MDUI logos used by this role\n\n```\nSP.logos(aspect)\n# => [Logo{}, Logo{}, Logo{}]\n```","ref":"SmeeView.Aspects.SP.html#logos/1"},{"type":"function","title":"SmeeView.Aspects.SP.protocols/1","doc":"Returns a list of protocol aspects for this role\n\n```\nSP.protocols(aspect)\n# => [%Protocol{}, %Protocol{}]\n```","ref":"SmeeView.Aspects.SP.html#protocols/1"},{"type":"function","title":"SmeeView.Aspects.SP.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nSP.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.SP.html#role/1"},{"type":"function","title":"SmeeView.Aspects.SP.services/1","doc":"Lists all types of services for this role\n\n```\nSP.services(aspect)\n# => [%SingleSignOnService{}, %SingleLogoutService{}]\n```","ref":"SmeeView.Aspects.SP.html#services/1"},{"type":"function","title":"SmeeView.Aspects.SP.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nSP.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.SP.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.SP.want_assertions_signed?/1","doc":"Returns true if the SP wants assertions to besigned\n\n```\nSP.want_assertions_signed?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.SP.html#want_assertions_signed?/1"},{"type":"type","title":"SmeeView.Aspects.SP.t/0","doc":"","ref":"SmeeView.Aspects.SP.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.Scope","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.Scope.html"},{"type":"function","title":"SmeeView.Aspects.Scope.domain/1","doc":"Returns the domain of the scope as a string (whether or not it is a regex)\n\n```\nScope.domain(aspect)\n# => \"example.com\"\n```","ref":"SmeeView.Aspects.Scope.html#domain/1"},{"type":"function","title":"SmeeView.Aspects.Scope.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nScope.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.Scope.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.Scope.regex?/1","doc":"Does the scope ask to be treated as a regular expression? Returns true if scope is a regex.\n\n```\nScope.regex?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Scope.html#regex?/1"},{"type":"function","title":"SmeeView.Aspects.Scope.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nScope.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.Scope.html#role/1"},{"type":"function","title":"SmeeView.Aspects.Scope.scope/1","doc":"Returns the domain of the scope as a string (whether or not it is a regex)\n\n```\nScope.scope(aspect)\n# => \"example.com\"\n```","ref":"SmeeView.Aspects.Scope.html#scope/1"},{"type":"function","title":"SmeeView.Aspects.Scope.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nScope.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.Scope.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.Scope.text/1","doc":"Returns the domain of the scope as a string (whether or not it is a regex)\n\n```\nScope.text(aspect)\n# => \"example.com\"\n```","ref":"SmeeView.Aspects.Scope.html#text/1"},{"type":"type","title":"SmeeView.Aspects.Scope.t/0","doc":"","ref":"SmeeView.Aspects.Scope.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.ServiceDescription","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.ServiceDescription.html"},{"type":"function","title":"SmeeView.Aspects.ServiceDescription.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nServiceDescription.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.ServiceDescription.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.ServiceDescription.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nServiceDescription.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.ServiceDescription.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.ServiceDescription.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nServiceDescription.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.ServiceDescription.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.ServiceDescription.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nServiceDescription.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.ServiceDescription.html#role/1"},{"type":"function","title":"SmeeView.Aspects.ServiceDescription.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nServiceDescription.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.ServiceDescription.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.ServiceDescription.text/1","doc":"Returns the text for the aspect.\n\nIf you are trying to show the text for a particular language then use a function from the matching View\n  instead, and provide a list of aspects for it to choose from.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nServiceDescription.text(aspect)\n# => \"Example University IdP\"\n```","ref":"SmeeView.Aspects.ServiceDescription.html#text/1"},{"type":"type","title":"SmeeView.Aspects.ServiceDescription.t/0","doc":"","ref":"SmeeView.Aspects.ServiceDescription.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.ServiceName","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.ServiceName.html"},{"type":"function","title":"SmeeView.Aspects.ServiceName.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nServiceName.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.ServiceName.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.ServiceName.lang/1","doc":"Returns the language of this aspect (as a two letter ISO 639-1 code)\n\nIf no language code has been set for this aspect then the default language code will be returned.\n\n```\nServiceName.lang(aspect)\n# => \"fr\"\n```","ref":"SmeeView.Aspects.ServiceName.html#lang/1"},{"type":"function","title":"SmeeView.Aspects.ServiceName.lang?/2","doc":"Is the aspect using this language? (two letter ISO 639-1 code)\n\nReturns true if the provided code matches that of the aspect.\n\nIf no language code has been set for this aspect then the aspect will be assumed to have\nthe default language code.\n\n```\nServiceName.lang?(aspect, \"en\")\n# => false\n```","ref":"SmeeView.Aspects.ServiceName.html#lang?/2"},{"type":"function","title":"SmeeView.Aspects.ServiceName.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nServiceName.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.ServiceName.html#role/1"},{"type":"function","title":"SmeeView.Aspects.ServiceName.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nServiceName.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.ServiceName.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.ServiceName.text/1","doc":"Returns the text for the aspect.\n\nIf you are trying to show the text for a particular language then use a function from the matching View\n  instead, and provide a list of aspects for it to choose from.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nServiceName.text(aspect)\n# => \"Example University IdP\"\n```","ref":"SmeeView.Aspects.ServiceName.html#text/1"},{"type":"type","title":"SmeeView.Aspects.ServiceName.t/0","doc":"","ref":"SmeeView.Aspects.ServiceName.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.SigningMethod","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.SigningMethod.html"},{"type":"function","title":"SmeeView.Aspects.SigningMethod.algorithm/1","doc":"Returns the name/text for this algorithm.\n\nAspects containing text are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nSigningMethod.algorithm(aspect)\n# => \"http://www.w3.org/2001/04/xmldsig-more#ecdsa-sha1\"\n```","ref":"SmeeView.Aspects.SigningMethod.html#algorithm/1"},{"type":"function","title":"SmeeView.Aspects.SigningMethod.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nSigningMethod.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.SigningMethod.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.SigningMethod.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nSigningMethod.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.SigningMethod.html#role/1"},{"type":"function","title":"SmeeView.Aspects.SigningMethod.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nSigningMethod.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.SigningMethod.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.SigningMethod.truncate/1","doc":"Removes the namespace for the algorithm, leaving a smaller, friendlier, potentially colliding name\n\n```\nSigningMethod.truncate(aspect)\n# => \"ecdsa-sha1\"\n```","ref":"SmeeView.Aspects.SigningMethod.html#truncate/1"},{"type":"type","title":"SmeeView.Aspects.SigningMethod.t/0","doc":"","ref":"SmeeView.Aspects.SigningMethod.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.SingleLogoutService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.SingleLogoutService.html"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nSingleLogoutService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nSingleLogoutService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nSingleLogoutService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nSingleLogoutService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nSingleLogoutService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nSingleLogoutService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.SingleLogoutService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nSingleLogoutService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.SingleLogoutService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.SingleLogoutService.t/0","doc":"","ref":"SmeeView.Aspects.SingleLogoutService.html#t:t/0"},{"type":"module","title":"SmeeView.Aspects.SingleSignonService","doc":"Represents and processes   elements in entity metadata as Aspect structs.\n\nThe functions in this module are intended to be applied to individual Aspect structs - for extracting and processing\ncollections of these records please use the matching View module.","ref":"SmeeView.Aspects.SingleSignonService.html"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.binding/1","doc":"Returns the binding type for this endpoint/service\n\n```\nSingleSignonService.binding(aspect)\n# => \"urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST\"\n```","ref":"SmeeView.Aspects.SingleSignonService.html#binding/1"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.endpoint/1","doc":"Returns the endpoint URL for this endpoint/service.\n\nAspects containing URLs are printable and can be converted to strings using `Kernel.to_string/1` or\n  interpolated into another string.\n\n```\nSingleSignonService.endpoint(aspect)\n# => \"https://test.ukfederation.org.uk/Shibboleth.sso/SAML2/POST\"\n```","ref":"SmeeView.Aspects.SingleSignonService.html#endpoint/1"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.idp?/1","doc":"Is this aspect relevant to the IdP role?\n\nWill return `true` if the aspect has been derived from an IdP role, or is applicable to all roles.\n\n```\nSingleSignonService.idp?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.SingleSignonService.html#idp?/1"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.index/1","doc":"Returns the index type for this endpoint/service, as an integer.\n\n```\nSingleSignonService.index(aspect)\n# => 1\n```","ref":"SmeeView.Aspects.SingleSignonService.html#index/1"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.role/1","doc":"Returns the associated role for this aspect: :sp, :idp or :all\n\nThe role type is useful when handling a mixed list of aspects that may be specific to certain roles of an\n  entity.\n\n```\nSingleSignonService.role(aspect)\n# => :idp\n```","ref":"SmeeView.Aspects.SingleSignonService.html#role/1"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.sp?/1","doc":"Is this aspect relevant to the SP role?\n\nWill return `true` if the aspect has been derived from an SP role, or is applicable to all roles.\n\n```\nSingleSignonService.sp?(aspect)\n# => false\n```","ref":"SmeeView.Aspects.SingleSignonService.html#sp?/1"},{"type":"function","title":"SmeeView.Aspects.SingleSignonService.valid?/1","doc":"Is the URL for this endpoint/service valid? Returns true if the endpoint URL can be parsed\n\n```\nSingleSignonService.valid?(aspect)\n# => true\n```","ref":"SmeeView.Aspects.SingleSignonService.html#valid?/1"},{"type":"type","title":"SmeeView.Aspects.SingleSignonService.t/0","doc":"","ref":"SmeeView.Aspects.SingleSignonService.html#t:t/0"},{"type":"extras","title":"SmeeView","doc":"# SmeeView\n\n`SmeeView` is a metadata parsing extension to [Smee](https://github.com/Digital-Identity-Labs/smee). SmeeView provides\neasy to use functions for extracting lists of information from SAML metadata as Elixir structs.\n\n[Smee](https://github.com/Digital-Identity-Labs/smee) provides access to entity metadata XML as both strings and parsed\n`xmerl` records but leaves the user to find and extract the information they need. SmeeView aims to fill this gap by\nproviding tools for working with the most commonly used information in SAML metadata.\n\nSmeeView is *loosely* based on the concept of functional data access \"lenses\".\n\n[![Hex pm](http://img.shields.io/hexpm/v/smee_view.svg?style=flat)](https://hex.pm/packages/smee_view)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](http://hexdocs.pm/smee_view/)\n![Github Elixir CI](https://github.com/Digital-Identity-Labs/smee_view/workflows/Elixir%20CI/badge.svg)\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fraw.githubusercontent.com%2FDigital-Identity-Labs%2Fsmee_view%2Fmain%2Fsmee_view_notebook.livemd)","ref":"readme.html"},{"type":"extras","title":"Features - SmeeView","doc":"* Relatively low memory usage and decent speed, especially when extracting smaller fragments of information\n* Aspects can be extracted from individual `Smee.Entity` or `Smee.Metadata` structs, lists of them, or even other\n  aspects.\n* Aspects are extracted as either lists or as lists in maps, associated with entity IDs.\n* Filters and tools are provided for handling aspects such as logos or multilingual text, and for checking commonly used\n  entity attributes.","ref":"readme.html#features"},{"type":"extras","title":"Overview - SmeeView","doc":"#","ref":"readme.html#overview"},{"type":"extras","title":"Views - SmeeView","doc":"View modules take metadata, or information extracted from metadata, and return a specific type of record from it, known\nas an aspect. They also allow further filtering and processing of lists of aspects.\n\nFor instance `SmeeView.Logos` can extract all logo information from an entity's metadata and filter them so that only\nIdP logos of a particular shape are returned. `SmeeView.Contacts` provides tools for extracting and filtering\n`SmeeView.Aspects.Contact` records.\n\n#","ref":"readme.html#views"},{"type":"extras","title":"Aspects - SmeeView","doc":"Each fragment of information extracted from metadata by a View is an *aspect*. Aspects contain most (if not all) of\nthe information present in the original metadata. Aspect modules provide ways to view or process that information.\n\nSome aspects contain bundles of other aspects:\n\n* A `SmeeView.Aspects.DiscoUI` struct contains lists of types of aspects useful for metadata discovery\n* `SmeeView.Aspects.IdP` structs contain all aspects related to an entity's IdP role\n\n#","ref":"readme.html#aspects"},{"type":"extras","title":"Convenience functions - SmeeView","doc":"The top level `SmeeView` module contains simplified, top level functions for extracting all the information for an\nentity.\nOther modules in SmeeView contain functions dedicated to specific types of information - one for extracting collections\nof\n\"aspects\", the other for working with individual records.","ref":"readme.html#convenience-functions"},{"type":"extras","title":"Examples - SmeeView","doc":"#","ref":"readme.html#examples"},{"type":"extras","title":"Extracting all data for an entity (using Smee's MDQ module) - SmeeView","doc":"```elixir\nalias Smee.MDQ\n\nMDQ.source(\"http://mdq.ukfederation.org.uk/\")\n|> MDQ.lookup!(\"https://cern.ch/login\")\n|> SmeeView.view_one()\n# => %SmeeView.Aspects.Entity{\n#       entity_id: \"https://cern.ch/login\",\n#       cache_duration: \"P0Y0M0DT6H0M0.000S\",\n#       registration: [\n#         %SmeeView.Aspects.Registration{\n#           authority: \"http://rr.aai.switch.ch/\",\n#           instant: \"2014-07-29T13:17:52Z\",\n#           policies: [\n#             %SmeeView.Aspects.RegistrationPolicy{\n#               lang: \"en\",\n#               url: \"https://www.switch.ch/aai/federation/switchaai/metadata-registration-practice-statement-20110711.txt\"\n#            }\n#          ]\n#         }\n#        ],\n#        publications: [],\n#        idps: [\n#          %SmeeView.Aspects.IdP{\n#            protocols: [\n#              %SmeeView.Aspects.Protocol{\n#                role: :idp,\n#                uri: \"urn:oasis:names:tc:SAML:2.0:protocol\"\n#             }\n# ...\n```\n\n#","ref":"readme.html#extracting-all-data-for-an-entity-using-smee-s-mdq-module"},{"type":"extras","title":"Viewing all logos in an entire federation - SmeeView","doc":"```elixir\nSmee.source(\"http://metadata.ukfederation.org.uk/ukfederation-metadata.xml\")\n|> Smee.fetch!()\n|> SmeeView.Logos.view()\n## => [\n#%SmeeView.Aspects.Logo{\n#  url: \"https://idp2.iay.org.uk/images/heads_80x80.jpg\",\n#  role: :idp,\n#  height: 80,\n#  width: 80,\n#  lang: \"en\"\n#},\n#%SmeeView.Aspects.Logo{\n#url: \"https://idp2.iay.org.uk/images/heads_100x43.jpg\",\n#     role: :idp,\n#height: 43,\n#width: 100,\n#lang: \"en\"\n#},\n#...\n```\n \n\n#","ref":"readme.html#viewing-all-logos-in-an-entire-federation"},{"type":"extras","title":"Selecting the best service displayname for a French user - SmeeView","doc":"```elixir\nentity\n|> SmeeView.Displaynames.view()\n|> SmeeView.Displaynames.pick(\"fr\")\n|> SmeeView.Aspects.Displayname.text()\n# => \"Plateforme pédagogique de pré-production de l'Université de Rouen Normandie\"\n```\n\n#","ref":"readme.html#selecting-the-best-service-displayname-for-a-french-user"},{"type":"extras","title":"Get the friendly names of all attributes required by a particular entity - SmeeView","doc":"```elixir\nthe_entity\n|> SmeeView.RequestedAttributes.view()\n|> SmeeView.RequestedAttributes.required_filter()\n|> SmeeView.RequestedAttributes.friendly_names()\n# => [\"email\", \"eppn\"]\n```\n\n#","ref":"readme.html#get-the-friendly-names-of-all-attributes-required-by-a-particular-entity"},{"type":"extras","title":"Find all the tiny square logos for IdPs in PNG format in German - SmeeView","doc":"(It's a very contrived example)\n\n```elixir\nSmee.source(\"http://metadata.ukfederation.org.uk/ukfederation-metadata.xml\")\n|> Smee.fetch!()\n|> SmeeView.Logos.view(:idp)\n|> Enum.filter(\n     fn logo ->\n       SmeeView.Aspects.Logo.size(logo) == :tiny &&\n         SmeeView.Aspects.Logo.shape(logo) == :square &&\n         SmeeView.Aspects.Logo.format(logo) == :png && \n         SmeeView.Aspects.Logo.lang(logo) == \"de\"\n     end\n   )\n# => []\n```\n\n#","ref":"readme.html#find-all-the-tiny-square-logos-for-idps-in-png-format-in-german"},{"type":"extras","title":"List the assurance certifications of each entity in a federation - SmeeView","doc":"This demonstrates the usefulness of prism views \n\n```elixir\nSmee.source(\"http://metadata.ukfederation.org.uk/ukfederation-metadata.xml\")\n|> Smee.fetch!()\n|> SmeeView.EntityAttributes.prism()\n|> SmeeView.EntityAttributes.assurance_certifications()\n# => %{\n#        \"https://stanford.dserec.com/sp\" => [\"https://refeds.org/sirtfi\"],\n#        \"https://iam.nnfc.re.kr/idp/simplesamlphp\" => [\"https://refeds.org/sirtfi\"],\n#        \"http://idp.vr.se/adfs/services/trust\" => [\"http://www.swamid.se/policy/assurance/al1\"],\n#        ...\n```","ref":"readme.html#list-the-assurance-certifications-of-each-entity-in-a-federation"},{"type":"extras","title":"Installation - SmeeView","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `smee_view` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:smee_view, \"~> 0.2.0\"}\n  ]\nend\n```\n\nSmeeView requires [Smee](https://github.com/Digital-Identity-Labs/smee), which has its own unusual requirements, so\nplease make sure you read the documentation for installing Smee before using SmeeView.","ref":"readme.html#installation"},{"type":"extras","title":"References and further reading - SmeeView","doc":"SmeeView does not document SAML Metadata itself - you'll need to read about that elsewhere if you have questions about\nhow the information is used. The following resources will be of help:\n\n* [Incommon's Guide to SAML Metadata](https://spaces.at.internet2.edu/display/federation/metadata-saml) - very clear and\n  readable\n* [OASIS Simplified Overview of SAML Metadata](https://www.oasis-open.org/committees/download.php/51890/SAML%20MD%20simplified%20overview.pdf)\n* [Wikipedia: SAML Metadata](https://en.wikipedia.org/wiki/SAML_metadata) Has technical overview, history and protocol\n  walkthrough","ref":"readme.html#references-and-further-reading"},{"type":"extras","title":"Documentation - SmeeView","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - SmeeView","doc":"You can request new features by creating an [issue](https://github.com/Digital-Identity-Labs/smee_view/issues),\nor submit a [pull request](https://github.com/Digital-Identity-Labs/smee_view/pulls) with your contribution.\n\nIf you are comfortable working with Python but Smee's Elixir code is unfamiliar then this blog post may help:\n[Elixir For Humans Who Know Python](https://hibox.live/elixir-for-humans-who-know-python)","ref":"readme.html#contributing"},{"type":"extras","title":"Copyright and License - SmeeView","doc":"Copyright (c) 2023, 2024 Digital Identity Ltd, UK\n\nSmeeView is Apache 2.0 licensed.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Disclaimer - SmeeView","doc":"SmeeView is not endorsed by The Shibboleth Foundation or any other organisation described in these docs.\nThe API will definitely change considerably in the first few releases after 0.1.0 - it is not stable!","ref":"readme.html#disclaimer"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}